<?php
/**
 * This file provides icon definitions through a function.
 *
 * Will resolve translations at runtime and consume less memory than a table.
 *
 * @package pond
 */
if( !defined('QP_CONFIG_LOADED') ) die( 'Please, do not access this page directly.' );


/**
 * Get icon according to an item.
 *
 * @param string icon name/key
 * @return array array( 'file' (relative to $rsc_path/$rsc_url), 'alt', 'size', 'class', 'rollover' )
 */
function get_icon_info($name)
{
	switch($name)
	{
		case 'activate':
		return array(
			'file' => 'icons/activate.png',
			'alt'  => /* TRANS: Short for "Activate(d)" */ T_('Act.'),
			'size' => array( 16, 16 ),
			'legend' => T_('Activate'),
		);
		case 'permalink':
		return array(
			'file' => 'icons/bean.png',
			'alt'  => T_('Permalink'),
			'size' => array( 11, 11 ),
			'rollover' => true,
		);
		case 'pixel':
		return array(
			'file' => 'icons/blank.gif',
			'alt'  => '',
			'size' => array( 1, 1 ),
		);
		case 'switch-to-blog':
		return array(
			'file' => 'icons/blog.png',
			'alt'  => /* TRANS: short for "Switch to _B_log" */ T_('Blg'),
			'size' => array( 16, 16 ),
		);
		case 'deprecate':
		return array(
			'file' => 'icons/blog-minus.png',
			'alt'  => T_('Deprecate'),
			'size' => array( 16, 16 ),
		);
		case 'publish':
		return array(
			'file' => 'icons/blog-plus.png',
			'alt'  => T_('Publish'),
			'size' => array( 16, 16 ),
		);
		case 'disabled':
		return array(
			'file' => 'icons/bullet-empty.png',
			'alt'  => /* TRANS: Short for "Deactivate(d)" */ T_('Deact.'),
			'size' => array( 9, 9 ),
			'legend' => T_('Deactivated'),
		);
		case 'enabled':
		return array(
			'file' => 'icons/bullet-full.png',
			'alt'  => /* TRANS: Short for "Activate(d)" */ T_('Act.'),
			'size' => array( 9, 9 ),
			'legend' => T_('Activated'),
		);
		case 'link':
		return array(
			'file' => 'icons/chain-link.png',
			'alt'  => /* TRANS: Link + space => verb (not noun) */ T_('Link '),
			'size' => array( 16, 16 ),
		);
		case 'unlink':
		return array(
			'file' => 'icons/chain-unlink.png',
			'alt'  => T_('Unlink'),
			'size' => array( 16, 16 ),
		);
		case 'check_all':
		return array(
			'file' => 'icons/check-all.png',
			'alt'  => T_('Check all'),
			'size' => array( 16, 16 ),
		);
		case 'history':
		return array(
			'file' => 'icons/clock.png',
			'alt'  => T_('History'),
			'size' => array( 16, 16 ),
		);
		case 'close':
		return array(
			'file' => 'icons/close.png',
			'alt' => T_('Close'),
			'size' => array( 16, 16 ),
			'rollover' => true,
		);
		case 'collapse':
		return array(
			'file' => 'icons/collapse.png',
			'alt'  => '-',
			'size' => array( 16, 16 ),
			'legend' => T_('Collapse'),
		);
		case 'comments':
		return array(
			'file' => 'icons/comments.png',
			'alt'  => T_('Comments'),
			'size' => array( 16, 16 ),
		);
		case 'copy':
		return array(
			'file' => 'icons/copy.png',
			'alt'  => T_('Copy'),
			'size' => array( 16, 16 ),
		);
		case 'deactivate':
		return array(
			'file' => 'icons/deactivate.png',
			'alt'  => /* TRANS: Short for "Deactivate(d)" */ T_('Deact.'),
			'size' => array( 16, 16 ),
			'legend' => T_('Deactivate'),
		);
		case 'decrease':
		return array(
			'file' => 'icons/decrease.png',
			'alt' => T_('-'),
			'size' => array( 16, 16 ),
			'rollover' => true,
		);
		case 'delete':
		return array(
			'file' => 'icons/document-cross.png',
			'alt'  => T_('Delete'),
			'size' => array( 16, 16 ),
		);
		case 'move':
		return array(
			'file' => 'icons/document-move.png',
			'alt'  => T_('Move'),
			'size' => array( 16, 16 ),
		);
		case 'edit':
		return array(
			'file' => 'icons/document-pencil.png',
			'alt'  => T_('Edit'),
			'size' => array( 16, 16 ),
		);
		case 'download':
		return array(
			'file' => 'icons/download.png',
			'alt'  => T_('Download'),
			'size' => array( 16, 16 ),
		);
		case 'expand':
		return array(
			'file' => 'icons/expand.png',
			'alt'  => '+',
			'size' => array( 16, 16 ),
			'legend' => T_('Expand'),
		);
		case 'feed':
		return array(
			'file' => 'icons/feed.png',
			'alt'  => T_('XML Feed'),
			'size' => array( 16, 16 ),
		);
		case 'folder':
		return array(
			'file' => 'icons/folder.png',
			'alt'  => T_('Folder'),
			'size' => array( 16, 16 ),
		);
		case 'reset_filters':
		return array(
			'file' => 'icons/funnel-reset.png',
			'alt'  => T_('Reset all filters'),
			'size' => array( 16, 16 ),
		);
		case 'switch-to-admin':
		return array(
			'file' => 'icons/hammer-screwdriver.png',
			'alt'  => /* TRANS: short for "Switch to _A_dmin" */ T_('Adm'),
			'size' => array( 16, 16 ),
		);
		case 'star_off':
		return array(
			'file' => 'icons/heart-small-empty.png',
			'alt'  => '-',
			'size' => array( 12, 12 ),
		);
		case 'star_on':
		return array(
			'file' => 'icons/heart-small-full.png',
			'alt'  => '*',
			'size' => array( 12, 12 ),
		);
		case 'star_half':
		return array(
			'file' => 'icons/heart-small-half.png',
			'alt'  => '+',
			'size' => array( 12, 12 ),
		);
		case 'increase':
		return array(
			'file' => 'icons/increase.png',
			'alt' => T_('+'),
			'size' => array( 16, 16 ),
			'rollover' => true,
		);
		case 'info':
		return array(
			'file' => 'icons/info.png',
			'alt'  => T_('Info'),
			'size' => array( 16, 16 ),
		);
		case 'not_allowed':
		return array(
			'file' => 'icons/lock-locked.png',
			'alt'  => T_( 'Blocked' ),
			'size' => array( 16, 16 ),
		);
		case 'allowed':
		return array(
			'file' => 'icons/lock-unlock.png',
			'alt'  => T_( 'Allowed' ),
			'size' => array( 16, 16 ),
		);
		case 'email':
		return array(
			'file' => 'icons/mail.png',
			'alt'  => T_('Email'),
			'size' => array( 16, 16 ),
		);
		case 'search':
		return array(
			'file' => 'icons/magnifier-arrow.png',
			'alt'  => T_('-&gt;S'),
			'size' => array( 16, 16 ),
		);
		case 'manual':
		return array(
			'file' => 'icons/manual.png',
			'alt'  => T_('Help'),
			'size' => array( 16, 16 ),
			'legend' => T_('Online Manual'),
			'rollover' => true,
		);
		case 'move_down':
		return array(
			'file' => 'icons/movedown.png',
			'alt'  => T_( 'Down'),
			'size' => array( 16, 16 ),
		);
		case 'move_up':
		return array(
			'file' => 'icons/moveup.png',
			'alt'  => T_( 'Up' ),
			'size' => array( 16, 16 ),
		);
		case 'move_left':
		return array(
			'file' => 'icons/left.png',
			'alt'  => T_( 'Up' ),
			'size' => array( 16, 16 ),
		);
		case 'move_right':
		return array(
			'file' => 'icons/right.png',
			'alt'  => T_( 'Up' ),
			'size' => array( 16, 16 ),
		);
		case 'new':
		return array(
			'file' => 'icons/new.png',
			'alt'  => T_('New'),
			'size' => array( 16, 16 ),
		);
		case 'nocomment':
		return array(
			'file' => 'icons/nocomments.png',
			'alt'  => T_('Comments'),
			'size' => array( 16, 16 ),
		);
		case 'nomove':
		return array(
			'file' => 'icons/nomove.png',
			'size' => array( 16, 16 ),
		);
		case 'nomove_down':
		return array(
			'file' => 'icons/nomovedown.png',
			'alt'  => T_( 'Sort by order' ),
			'size' => array( 16, 16 ),
		);
		case 'nomove_up':
		return array(
			'file' => 'icons/nomoveup.png',
			'alt'  => T_( 'Sort by order' ),
			'size' => array( 16, 16 ),
		);
		case 'parent_childto_arrow':
		return array(
			'file' => 'icons/parent-childto-arrow.png',
			'alt'  => T_('+'),
			'size' => array( 16, 16 ),
		);
		case 'permission':
		return array(
			'file' => 'icons/permission.png',
			'alt'  => T_('Permissions'),
			'size' => array( 16, 16 ),
		);
		case 'properties':
		return array(
			'file' => 'icons/properties.png',
			'alt'  => T_('Properties'),
			'size' => array( 16, 16 ),
		);
		case 'help':
		return array(
			'file' => 'icons/question.png',
			'alt'  => T_('Help'),
			'size' => array( 16, 16 ),
		);
		case 'refresh':
		return array(
			'file' => 'icons/refresh.png',
			'alt'  => T_('Refresh'),
			'size' => array( 16, 16 ),
		);
		case 'reload':
		return array(
			'file' => 'icons/reload.png',
			'alt'  => T_('Reload'),
			'size' => array( 16, 16 ),
		);
		case 'rename':
		return array(
			'file' => 'icons/rename.png',
			'alt'  => T_('Rename'),
			'size' => array( 16, 16 ),
		);
		case 'ban':
		return array(
			'file' => 'icons/slash.png',
			'alt'  => /* TRANS: Abbrev. */ T_('Ban'),
			'size' => array( 16, 16 ),
		);
		case 'ascending':
		return array(
			'file' => 'icons/sort-alphabet-az.png',
			'alt'  => /* TRANS: Short (alt tag) for "Ascending" */ T_('A'),
			'size' => array( 16, 16 ),
		);
		case 'descending':
		return array(
			'file' => 'icons/sort-alphabet-za.png',
			'alt'  => /* TRANS: Short (alt tag) for "Descending" */ T_('D'),
			'size' => array( 16, 16 ),
		);
		case 'locate':
		return array(
			'file' => 'icons/target.png',
			'alt'  => T_('Locate'),
			'size' => array( 16, 16 ),
		);
		case 'allowback':
		return array(
			'file' => 'icons/tick.png',
			'alt'  => T_('Allow back'),
			'size' => array( 16, 16 ),
		);
		case 'uncheck_all':
		return array(
			'file' => 'icons/uncheck-all.png',
			'alt'  => T_('Uncheck all'),
			'size' => array( 16, 16 ),
		);
		case 'folder_parent':
		return array( // -------------------------------------> not a good icon :(
			'file' => 'icons/up.png',
			'alt'  => T_('Parent folder'),
			'size' => array( 16, 16 ),
		);
		case 'upload':
		return array(
			'file' => 'icons/upload.png',
			'alt'  => T_('Upload'),
			'size' => array( 16, 16 ),
		);
		case 'www':
		return array(
			'file' => 'icons/url.png',
			'alt'  => T_('WWW'),
			'size' => array( 32, 16 ),
			'legend' => T_('Website'),
		);
		case 'warning':
		return array(
			'file' => 'icons/warning.png',
			'alt'  => T_('Warning'),
			'size' => array( 16, 16 ),
		);
		case 'window_new':
		return array(
			'file' => 'icons/window-new.png',
			'alt'  => T_('New window'),
			'size' => array( 16, 16 ),
		);

		// cases for file type icons, in fileicons folder
		case 'file_css':
		return array(
			'file' => 'icons/fileicons/css.png',
			'alt'  => '',
			'size' => array( 16, 16 ),
		);
		case 'file_unknown':
		return array(
			'file' => 'icons/fileicons/default.png',
			'alt'  => T_('Unknown file'),
			'size' => array( 16, 16 ),
		);
		case 'file_doc':
		return array(
			'file' => 'icons/fileicons/doc.gif',
			'alt'  => '',
			'size' => array( 16, 16 ),
		);
		case 'file_html':
		return array(
			'file' => 'icons/fileicons/html.png',
			'alt'  => '',
			'size' => array( 16, 16 ),
		);
		case 'file_image':
		return array(
			'file' => 'icons/fileicons/image.png',
			'alt'  => '',
			'size' => array( 16, 16 ),
		);
		case 'file_m4a':
		return array(
			'file' => 'icons/fileicons/m4a.png',
			'alt'  => '',
			'size' => array( 16, 16 ),
		);
		case 'file_mov':
		return array(
			'file' => 'icons/fileicons/mov.png',
			'alt'  => '',
			'size' => array( 16, 16 ),
		);
		case 'file_mp3':
		return array(
			'file' => 'icons/fileicons/mp3.png',
			'alt'  => '',
			'size' => array( 16, 16 ),
		);
		case 'file_mp4':
		return array(
			'file' => 'icons/fileicons/mp4.png',
			'alt'  => '',
			'size' => array( 16, 16 ),
		);
		case 'file_pdf':
		return array(
			'file' => 'icons/fileicons/pdf.png',
			'alt'  => '',
			'size' => array( 16, 16 ),
		);
		case 'file_php':
		return array(
			'file' => 'icons/fileicons/php.png',
			'alt'  => '',
			'size' => array( 16, 16 ),
		);
		case 'file_pps':
		return array(
			'file' => 'icons/fileicons/pps.gif',
			'alt'  => '',
			'size' => array( 16, 16 ),
		);
		case 'file_ppt':
		return array(
			'file' => 'icons/fileicons/ppt.gif',
			'alt'  => '',
			'size' => array( 16, 16 ),
		);
		case 'file_text':
		return array(
			'file' => 'icons/fileicons/text.png',
			'alt'  => '',
			'size' => array( 16, 16 ),
		);
		case 'file_xls':
		return array(
			'file' => 'icons/fileicons/xls.gif',
			'alt'  => '',
			'size' => array( 16, 16 ),
		);
		case 'file_zip':
		return array(
			'file' => 'icons/fileicons/zip.gif',
			'alt'  => '',
			'size' => array( 16, 16 ),
		);
	}

}

?>
