<?php
/**
 * This file implements the CollectionSettings class which handles
 * coll_ID/name/value triplets for collections/blogs.
 *
 * This file is part of Quam Plures - {@link http://quamplures.net/}
 * See also {@link https://launchpad.net/quam-plures}.
 *
 * @copyright (c) 2009 by the Quam Plures developers - {@link http://quamplures.net/}
 * @copyright (c)2003-2009 by Francois PLANQUE - {@link http://fplanque.net/}
 *
 * {@internal License choice
 * - If you have received this file as part of a package, please find the license.txt file in
 *   the same folder or the closest folder above for complete license terms.
 * - If you have received this file individually (e-g: from http://evocms.cvs.sourceforge.net/)
 *   then you must choose one of the following licenses before using the file:
 *   - GNU General Public License 2 (GPL) - http://www.opensource.org/licenses/gpl-license.php
 *   - Mozilla Public License 1.1 (MPL) - http://www.opensource.org/licenses/mozilla1.1.php
 * }}
 *
 * {@internal Open Source relicensing agreement:
 * }}
 *
 * {@internal Below is a list of authors who have contributed to design/coding of this file: }}
 * @author fplanque: Francois PLANQUE
 *
 * @package collections
 */
if( !defined('QP_MAIN_INIT') ) die( 'Please, do not access this page directly.' );

load_class('settings/model/_abstractsettings.class.php');

/**
 * Class to handle the settings for collections/blogs
 *
 * @package collections
 */
class CollectionSettings extends AbstractSettings
{
	/**
	 * The default settings to use, when a setting is not defined in the database.
	 *
	 * @todo EdB: IMPORTANT! make this be configurable new blog defaults one day
	 * @access protected
	 */
	var $_defaults = array(
		// Blog settings -> General subtab
		// "Content / Posts" section
		'orderby'        => 'datestart',
		'orderdir'       => 'DESC',
		'what_to_show'   => 'posts', // 'posts', 'days'
		'posts_per_page' => '5', // * also on URLs subtab *
		'archive_mode'   => 'monthly', // 'monthly', 'weekly', 'daily', 'postbypost'
		// "Description" section
		'blog_footer_text'        => '&copy;$year$ by $owner$',
		'single_item_footer_text' => '',
		// "Meta data" section
		'xml_item_footer_text' => '<p><small><a href="$item_perm_url$">xml item footer text</small></p>',
		// "Aggregation" section
		'aggregate_coll_IDs' => '',

		// Blog settings -> Features subtab
		// "Post options" section
		'require_title' => 'required', // 'required', 'optional', 'none'
		// "Feedback options" section
		'allow_rating'        => 'never',
		'new_feedback_status' => 'draft', // 'draft', 'published', 'deprecated'
		// "RSS/Atom feeds" section
		'feed_content'   => 'normal',
		'posts_per_feed' => '8',
		// "Multiple authors" section
		'use_workflow' => 0,
		// "Subscriptions" section
		'allow_subscriptions' => 0,
		// "After each new post..." section
		'ping_plugins' => 'ping_pingomatic,ping_twitter', // ping plugin codes, separated by comma
		// "External Feeds" section
		'atom_redirect' => '',
		'rss2_redirect' => '',
		// "Caching [Admin]" section
		'cache_enabled' => 0,

		// Blog settings -> Categories subtab
		// "Categories for blog" section
		'default_cat_ID' => NULL,

		// Blog settings -> URLs subtab
		// "Main page / post list" section
		'default_noindex'       => '0',
		'canonical_homepage'    => 1,
		'relcanonical_homepage' => 1,
		'paged_noindex'         => '1',
		'paged_nofollowto'      => '0',
		'title_link_type'       => 'permalink',
		'main_content'          => 'normal',
		'permalinks'            => 'single', // 'single', 'archive', 'subchap'
		// "Single post pages / "Permalink" pages" section
		'single_links'              => 'ymd',
		'canonical_item_urls'       => 1,
		'relcanonical_item_urls'    => 1,
		'excerpts_meta_description' => '0',
		// "Category pages" section
		'chapter_links'               => 'chapters', // 'param_num', 'subchap', 'chapters'
		'category_prefix'             => '',
		'canonical_cat_urls'          => 1,
		'relcanonical_cat_urls'       => 1,
		'chapter_noindex'             => '1',
		'chapter_content'             => 'excerpt',
		'chapter_posts_per_page'      => NULL,
		'posts_per_page'              => '5', // * also on General subtab *
		'catdir_noindex'              => '1',
		'categories_meta_description' => '0',
		// "Tag pages" section
		'tag_links'             => 'colon', // 'param', 'colon', 'semicolon' -- fp> we want this changed to prefix only for new blogs only
		'tag_prefix'            => '', // fp> fp> we want this changed to prefix only for new blogs only
		'tag_rel_attrib'        => 1, // rel="tag" attribute for tag links (http://microformats.org/wiki/rel-tag) -- valid only in prefix-only mode
		'canonical_tag_urls'    => 1,
		'relcanonical_tag_urls' => 1,
		'tag_noindex'           => '1',
		'tag_content'           => 'excerpt',
		'tag_posts_per_page'    => NULL,
		// ""By date" archives" section
		'archive_links'             => 'extrapath', // param, extrapath
		'canonical_archive_urls'    => 1,
		'relcanonical_archive_urls' => 1,
		'archive_noindex'           => '1',
		'archive_nofollowto'        => '0',
		'archive_content'           => 'excerpt',
		'archive_posts_per_page'    => '100',
		'arcdir_noindex'            => '1',
		// "Other filtered pages" section
		'filtered_noindex' => '1',
		'filtered_content' => 'excerpt',
		// "Other pages" section
		'feedback-popup_noindex' => '1',
		'msgform_noindex'        => '1',
		'special_noindex'        => '1',
		'404_response'           => '404',
		);


	/**
	 * Constructor
	 */
	function CollectionSettings()
	{
		parent::AbstractSettings( 'T_coll_settings', array( 'cset_coll_ID', 'cset_name' ), 'cset_value', 1 );
	}

	/**
	 * Loads the settings. Not meant to be called directly, but gets called
	 * when needed.
	 *
	 * @access protected
	 * @param string First column key
	 * @param string Second column key
	 * @return boolean
	 */
	function _load( $coll_ID, $arg )
	{
		if( empty( $coll_ID ) )
		{
			return false;
		}

		return parent::_load( $coll_ID, $arg );
	}

}


?>
