<?php
/**
 * This file implements the UI view for the General blog properties.
 *
 * Quam Plures - {@link http://quamplures.net/}
 * Released under GNU GPL License - {@link http://quamplures.net/license.html}
 * @copyright (c) 2009 by the Quam Plures developers - {@link http://quamplures.net/}
 * @copyright (c)2003-2009 by Francois PLANQUE - {@link http://fplanque.net/}
 * Parts of this file are copyright (c)2004-2005 by Daniel HAHLER - {@link http://thequod.de/contact}.
 *
 * {@internal Open Source relicensing agreement:
 * Daniel HAHLER grants Francois PLANQUE the right to license
 * Daniel HAHLER's contributions to this file and the b2evolution project
 * under any OSI approved OSS license (http://www.opensource.org/licenses/).
 * }}
 *
 * {@internal Below is a list of authors who have contributed to design/coding of this file: }}
 * @author blueyed: Daniel HAHLER
 * @author fplanque: Francois PLANQUE.
 *
 * @package collections
 */
if( !defined('QP_MAIN_INIT') ) die( 'Please, do not access this page directly.' );

/**
 * @var Blog
 */
global $edited_Blog;

global $action, $next_action, $blogtemplate, $blog, $tab;

$Form = new Form();

$Form->begin_form( 'fform' );

$Form->hidden_ctrl();
$Form->hidden( 'action', $next_action );
$Form->hidden( 'tab', $tab );
if( $next_action == 'create' )
{
	$Form->hidden( 'kind', get_param('kind') );
	$Form->hidden( 'template_ID', get_param('template_ID') );
}
else
{
	$Form->hidden( 'blog', $blog );
}

$Form->begin_fieldset( T_('General parameters'), array( 'class'=>'fieldset clear' ) );
	$Form->text( 'blog_name', $edited_Blog->get( 'name' ), 50, T_('Title'), T_('Will be displayed on top of the blog.'), 255 );
	$Form->text( 'blog_shortname', $edited_Blog->get( 'shortname', 'formvalue' ), 15, T_('Short name'), T_('Will be used in selection menus and throughout the admin interface.'), 255 );

	$owner_User = & $edited_Blog->get_owner_User();
	if( $current_User->check_perm( 'blog_admin', 'edit', false, $edited_Blog->ID ) )
	{ // Permission to edit advanced admin settings
		$Form->text( 'blog_urlname', $edited_Blog->get( 'urlname' ), 20, T_('URL "filename"'),
			T_('"slug" used to uniquely identify this blog in URLs'), 255 );
		// fp> Note: There are 2 reasons why we don't provide a select here:
		// 1. If there are 1000 users, it's a pain.
		// 2. A single blog owner is not necessarily allowed to see all other users.
		$Form->text( 'owner_login', $owner_User->login, 20, T_('Owner'), T_('Login of this blog\'s owner.') );
	}
	else
	{
		$Form->info( T_('URL Name'), $edited_Blog->get( 'urlname' ), T_('Used to uniquely identify this blog in URLs.') /* Note: message voluntarily shorter than admin message */ );
		$Form->info( T_('Owner'), $owner_User->login, $owner_User->dget('fullname') );
	}

	$Form->select( 'blog_locale', $edited_Blog->get( 'locale' ), 'locale_options_return', T_('Main Locale'), T_('Determines the language of the navigation links on the blog.') );
$Form->end_fieldset();

$Form->begin_fieldset( T_('Content / Posts') );
	$Form->select_input_array( 'orderby', $edited_Blog->get_setting( 'orderby' ), get_available_sort_options(), T_('Order by'), T_('Default ordering of posts.') );
	$Form->select_input_array( 'orderdir', $edited_Blog->get_setting( 'orderdir' ), array(
		'ASC'  => T_('Ascending'),
		'DESC' => T_('Descending'),
	), T_('Direction') );
	$Form->radio( 'what_to_show', $edited_Blog->get_setting( 'what_to_show' ), array(
		array( 'days', T_('days') ),
		array( 'posts', T_('posts') )
	), T_('Display unit'), false, T_('Do you want to restrict on the number of days or the number of posts?') );
	$Form->text( 'posts_per_page', $edited_Blog->get_setting( 'posts_per_page' ), 4, T_('Posts/Days per page'), T_('How many days or posts do you want to display on the home page?'), 4 );
	$Form->radio( 'archive_mode', $edited_Blog->get_setting( 'archive_mode' ), array(
		array( 'monthly', T_('monthly') ),
		array( 'weekly', T_('weekly') ),
		array( 'daily', T_('daily') ),
		array( 'postbypost', T_('post by post') )
	), T_('Archive grouping'), false, T_('How do you want to browse the post archives? May also apply to permalinks.') );
$Form->end_fieldset();

$Form->begin_fieldset( T_('Description') );
	$Form->text( 'blog_tagline', $edited_Blog->get( 'tagline' ), 50, T_('Tagline'), T_('This is diplayed under the blog name on the blog template.'), 250 );
	$Form->textarea( 'blog_longdesc', $edited_Blog->get( 'longdesc' ), 5, T_('Long Description'), T_('This is displayed on the blog template.'), 50, 'large' );
	$Form->text( 'blog_footer_text', $edited_Blog->get_setting( 'blog_footer_text' ), 60, T_('Blog footer'), T_('Use &lt;br /&gt; to insert a line break.'), 1000, 'large' );
	$Form->textarea( 'single_item_footer_text', $edited_Blog->get_setting( 'single_item_footer_text' ), 2, T_('Single post footer'),
		T_('This will be displayed after each post in single post view.'), 50, 'large' );
$Form->end_fieldset();

$Form->begin_fieldset( get_manual_link('blog-meta-data').T_('Meta data') );
	// TODO: move stuff to coll_settings
	$Form->text( 'blog_description', $edited_Blog->get( 'description' ), 60, T_('Short Description'), T_('This is is used in meta tag description and RSS feeds. NO HTML!'), 250, 'large' );
	$Form->text( 'blog_keywords', $edited_Blog->get( 'keywords' ), 60, T_('Keywords'), T_('This is is used in meta tag keywords. NO HTML!'), 250, 'large' );
	$Form->textarea( 'xml_item_footer_text', $edited_Blog->get_setting( 'xml_item_footer_text' ), 2, T_('Post footer in RSS/Atom'), T_('This will be appended to each post in your RSS/Atom feeds.'), 50, 'large' );
	$Form->textarea( 'blog_notes', $edited_Blog->get( 'notes' ), 5, T_('Notes'), T_('Additional info. Appears in the backoffice.'), 50, 'large' );
$Form->end_fieldset();

if( $current_User->check_perm( 'blog_admin', 'edit', false, $edited_Blog->ID ) )
{ // Permission to edit advanced admin settings
	$Form->begin_fieldset( T_('Aggregation').' ['.T_('Admin').']' );
		$Form->text( 'aggregate_coll_IDs', $edited_Blog->get_setting( 'aggregate_coll_IDs' ), 30, T_('Blogs to aggregate'), T_('List blog IDs separated by ,'), 255 );
	$Form->end_fieldset();

	$Form->begin_fieldset( T_('Media directory location').' ['.T_('Admin').']' );
		global $media_path;
		$Form->radio( 'blog_media_location', $edited_Blog->get( 'media_location' ), array(
			array( 'none', T_('None') ),
			array( 'default', T_('Default'), $media_path.'blogs/id_'.$edited_Blog->ID.'/' ),
			array( 'subdir', T_('Subdirectory of media folder').':',
			'',
			' <span class="nobr"><code>'.$media_path.'</code><input
				type="text" name="blog_media_subdir" class="form_text_input" size="20" maxlength="255"
				class="'.( param_has_error('blog_media_subdir') ? 'field_error' : '' ).'"
				value="'.$edited_Blog->dget( 'media_subdir', 'formvalue' ).'" /></span>', '' ),
			array( 'custom',
				T_('Custom location').':',
				'',
				'<fieldset>'
					.'<div class="label">'.T_('directory').':</div><div class="input"><input
					type="text" class="form_text_input" name="blog_media_fullpath" size="50" maxlength="255"
					class="'.( param_has_error('blog_media_fullpath') ? 'field_error' : '' ).'"
					value="'.$edited_Blog->dget( 'media_fullpath', 'formvalue' ).'" /></div>'
					.'<div class="label">'.T_('URL').':</div><div class="input"><input
					type="text" class="form_text_input" name="blog_media_url" size="50" maxlength="255"
					class="'.( param_has_error('blog_media_url') ? 'field_error' : '' ).'"
					value="'.$edited_Blog->dget( 'media_url', 'formvalue' ).'" /></div></fieldset>' ) ),
				T_('Media directory'), true );
	$Form->end_fieldset();
}

$Form->buttons( array(
	array( 'submit', 'submit', T_('Save !'), 'SaveButton' ),
	array( 'reset', '', T_('Reset'), 'ResetButton' ) ) );

$Form->end_form();

?>
