<?php
/**
 * This file implements the GeneralSettings class, which handles Name/Value pairs.
 *
 * This file is part of Quam Plures - {@link http://quamplures.net/}
 * See also {@link https://launchpad.net/quam-plures}.
 *
 * @copyright (c) 2009 by the Quam Plures developers - {@link http://quamplures.net/}
 * @copyright (c)2003-2009 by Francois PLANQUE - {@link http://fplanque.net/}
 * Parts of this file are copyright (c)2004-2006 by Daniel HAHLER - {@link http://thequod.de/contact}.
 *
 * {@internal License choice
 * - If you have received this file as part of a package, please find the license.txt file in
 *   the same folder or the closest folder above for complete license terms.
 * - If you have received this file individually (e-g: from http://evocms.cvs.sourceforge.net/)
 *   then you must choose one of the following licenses before using the file:
 *   - GNU General Public License 2 (GPL) - http://www.opensource.org/licenses/gpl-license.php
 *   - Mozilla Public License 1.1 (MPL) - http://www.opensource.org/licenses/mozilla1.1.php
 * }}
 *
 * {@internal Open Source relicensing agreement:
 * Daniel HAHLER grants Francois PLANQUE the right to license
 * Daniel HAHLER's contributions to this file and the b2evolution project
 * under any OSI approved OSS license (http://www.opensource.org/licenses/).
 * }}
 *
 * {@internal Below is a list of authors who have contributed to design/coding of this file: }}
 * @author fplanque: Francois PLANQUE
 * @author blueyed: Daniel HAHLER
 *
 * @package pond
 */
if( !defined('QP_MAIN_INIT') ) die( 'Please, do not access this page directly.' );

load_class('settings/model/_abstractsettings.class.php');

/**
 * Class to handle the global settings.
 *
 * @package pond
 */
class GeneralSettings extends AbstractSettings
{
	/**
	 * The default settings to use, when a setting is not given
	 * in the database.
	 *
	 * The following are set and reset on Global settings -> general and have no defined defaults:
	 * 'eblog_server_host', 'eblog_username', 'eblog_password', 'eblog_novalidatecert', 
	 * 'eblog_body_terminator', 'eblog_test_mode', 'newusers_grp_ID', 'default_blog_ID',
	 *
	 * @todo EdB: IMPORTANT! make this be configurable new user defaults one day
	 * @todo (legacy): Allow overriding from /qp_config/_config_TEST.php?
	 * @access protected
	 * @var array
	 */
	var $_defaults = array(
		// Global settings -> General subtab
		// "After each new post..." section
		'outbound_notifications_mode' => 'immediate', // 'off', 'immediate', 'cron'
		// "Blog by email" section
		'eblog_enabled' => 0,
		'eblog_method' => 'pop3',
		'eblog_server_port' => 110,
		'eblog_encrypt' => 'none',
		'eblog_default_category' => 1,
		'eblog_subject_prefix' => 'blog:',
		'eblog_add_imgtag' => 1,
		'AutoBR' => 0,
		'eblog_body_terminator' => '___',
		// "Categories" section
		'allow_moving_chapters' => '0',
		'chapter_ordering' => 'alpha',
		// "Default user permissions" section
		'newusers_canregister' => '0',
		'newusers_level' => '1',
		// "Email validation" section
		'newusers_mustvalidate' => '1',
		'newusers_revalidate_emailchg' => '0',
		// "Features" section
		'fm_enabled' => '1',
		'general_cache_enabled' => 0,
		'webhelp_enabled' => '1',
		// "Hit & session logging" section
		'log_public_hits' => '1',
		'log_admin_hits' => '0',
		'auto_prune_stats_mode' => 'page', // 'off', 'page', 'cron'
		'auto_prune_stats' => '15',
		// "Security options" section
		'user_minpwdlen' => '5', 
		'js_passwd_hashing' => '1',
		// "Timeouts" section
		'timeout_sessions' => '604800', // (in seconds, 604800 == 7 days)
		'reloadpage_timeout' => '300',

		// Global settings -> Files subtab
		// "Accessible file roots" section
		'fm_enable_roots_blog' => '1',
		'fm_enable_roots_user' => '1',
		'fm_enable_roots_shared' => '1',
		'fm_enable_roots_templates' => '0',
		// "File creation options" section
		'fm_enable_create_dir' => '1',
		'fm_enable_create_file' => '1',
		'upload_enabled' => '1',
		'upload_maxkb' => '2048',
		// "Advanced options" section
		'fm_default_chmod_file' => '664',
		'fm_default_chmod_dir' => '775',
		'regexp_filename' => '^[a-zA-Z0-9\-_. ]+$', // TODO: accept (spaces and) special chars / do full testing on this
		'regexp_dirname' => '^[a-zA-Z0-9\-_]+$', // TODO: accept spaces and special chars / do full testing on this

		// not sorted by tab/subtab/section yet...
		'fm_showtypes' => '0',
		'fm_showfsperms' => '0',
		'log_spam_hits' => '0',
		'admin_template' => 'chicago', // obsolete?
		'antispam_last_update' => '2000-01-01 00:00:00',
		'antispam_threshold_publish' => '-90',
		'antispam_threshold_delete' => '100', // do not delete by default!
		'antispam_block_spam_referers' => '0',	// By default, let spam referers go in silently (just don't log them). This is in case the blacklist is too paranoid (social media, etc.)
		'antispam_report_to_central' => '1',
		'time_difference' => '0',
	);


	/**
	 * Constructor.
	 *
	 * This loads the general settings and checks db_version.
	 *
	 * It will also turn off error-reporting/halting of the {@link $DB DB object}
	 * temporarily to present a more decent error message if tables do not exist yet.
	 *
	 * Because the {@link $DB DB object} itself creates a connection when it gets
	 * created "Error selecting database" occurs before we can check for it here.
	 */
	function GeneralSettings()
	{
		global $app_db_version, $DB;

		$save_DB_show_errors = $DB->show_errors;
		$save_DB_halt_on_error = $DB->halt_on_error;
		$DB->halt_on_error = false;
		$DB->show_errors = false;

		// Init through the abstract constructor. This should be the first DB connection.
		parent::AbstractSettings( 'T_settings', array( 'set_name' ), 'set_value', 0 );


		// check DB version:
		if( $this->get( 'db_version' ) != $app_db_version )
		{ // Database is not up to date:
			if( $DB->last_error )
			{
				$error_message = '<p>MySQL error:</p>'.$DB->last_error;
			}
			else
			{
				$error_message = '<p>Database schema is not up to date!</p>'
					.'<p>You have schema version &laquo;'.(integer)$this->get( 'db_version' ).'&raquo;, '
					.'but we would need &laquo;'.(integer)$app_db_version.'&raquo;.</p>';
			}
			global $admintemplates_path;
			require $admintemplates_path.'conf_error.main.php'; // error & exit
		}

		$DB->halt_on_error = $save_DB_halt_on_error;
		$DB->show_errors = $save_DB_show_errors;
	}


	/**
	 * Get a 32-byte string that can be used as salt for public keys.
	 *
	 * @return string
	 */
	function get_public_key_salt()
	{
		$public_key_salt = $this->get( 'public_key_salt' );
		if( empty($public_key_salt) )
		{
			$public_key_salt = generate_random_key(32);
			$this->set( 'public_key_salt', $public_key_salt );
			$this->dbupdate();
		}
		return $public_key_salt;
	}

}



?>
