<?php
/**
 * This file implements the UI view for the general settings.
 *
 * This file is part of Quam Plures - {@link http://quamplures.net/}
 * See also {@link https://launchpad.net/quam-plures}.
 *
 * @copyright (c) 2009 by the Quam Plures developers - {@link http://quamplures.net/}
 * @copyright (c)2003-2009 by Francois PLANQUE - {@link http://fplanque.net/}
 *
 * {@internal License choice
 * - If you have received this file as part of a package, please find the license.txt file in
 *   the same folder or the closest folder above for complete license terms.
 * - If you have received this file individually (e-g: from http://evocms.cvs.sourceforge.net/)
 *   then you must choose one of the following licenses before using the file:
 *   - GNU General Public License 2 (GPL) - http://www.opensource.org/licenses/gpl-license.php
 *   - Mozilla Public License 1.1 (MPL) - http://www.opensource.org/licenses/mozilla1.1.php
 * }}
 *
 * {@internal Open Source relicensing agreement:
 * }}
 *
 * {@internal Below is a list of authors who have contributed to design/coding of this file: }}
 * @author fplanque: Francois PLANQUE.
 * @author blueyed: Daniel HAHLER.
 *
 * @package pond
 */
if( !defined('QP_MAIN_INIT') ) die( 'Please, do not access this page directly.' );

/**
 * @var User
 */
global $current_User;

/**
 * @var GeneralSettings
 */
global $Settings;

global $dispatcher;

global $app_baseurl;

$Form = new Form( NULL, 'settings_checkchanges' );

$Form->begin_form( 'fform', T_('General Settings'),
	// enable all form elements on submit (so values get sent):
	array( 'onsubmit'=>'var es=this.elements; for( var i=0; i < es.length; i++ ) { es[i].disabled=false; };' ) );

$Form->hidden( 'ctrl', 'settings' );
$Form->hidden( 'action', 'update' );
$Form->hidden( 'tab', 'general' );

$Form->begin_fieldset( get_manual_link('after-each-new-post').T_('After each new post...') );
	$Form->radio_input( 'outbound_notifications_mode', $Settings->get( 'outbound_notifications_mode' ),
		array(
			array( 'value'=>'off', 'label'=>T_('Off'), 'note'=>T_('No notification about your new content will be sent out.') ),
			array( 'value'=>'immediate', 'label'=>T_('Immediate'), 'note'=>T_('This is guaranteed to work but may create an annoying delay after each post.') ),
			array( 'value'=>'cron', 'label'=>T_('Asynchronous'), 'note'=>T_('Recommended if you have your scheduled jobs properly set up.') )
		),
		T_('Outbound pings & email notifications'),
		array( 'lines' => true ) );
$Form->end_fieldset();

// --------------------------------------------

$Form->begin_fieldset( get_manual_link('blog_by_email').T_('Blog by email') );
	$Form->checkbox_input( 'eblog_enabled', $Settings->get( 'eblog_enabled' ), T_('Enable Blog by email'),
		array( 'note' => sprintf(T_('Note: This feature needs the php_imap extension (currently %s).' ), extension_loaded( 'imap' ) ? T_('loaded') : T_('NOT loaded')), 'onclick' =>
			'document.getElementById("eblog_section").style.display = (this.checked==true ? "" : "none") ;' ) );
	// fp> TODO: this is IMPOSSIBLE to turn back on when you have no javascript!!! :((
	echo '<div id="eblog_section" style="'.( $Settings->get( 'eblog_enabled' ) ? '' : 'display:none' ).'">';
		$Form->select_input_array( 'eblog_method', $Settings->get( 'eblog_method' ), array( 'pop3' => T_('POP3'), 'imap' => T_('IMAP'), ), // TRANS: E-Mail retrieval method
			T_('Retrieval method'), T_('Choose a method to retrieve the emails.') );
		$Form->text_input( 'eblog_server_host', $Settings->get( 'eblog_server_host' ), 40, T_('Mail Server'), T_('Hostname or IP address of your incoming mail server.'), array( 'maxlength' => 255 ) );
		$Form->text_input( 'eblog_server_port', $Settings->get( 'eblog_server_port' ), 5, T_('Port Number'), T_('Port number of your incoming mail server (Defaults: pop3: 110 imap: 143).'), array( 'maxlength' => 6 ) );
		$Form->radio( 'eblog_encrypt', $Settings->get( 'eblog_encrypt' ), array(
																			array( 'none', T_('None'), ),
																			array( 'ssl', T_('SSL'), ),
																			array( 'tls', T_('TLS'), ),
																		), T_('Encryption method') );
		$Form->text_input( 'eblog_username', $Settings->get( 'eblog_username' ), 15, T_('Account Name'), T_('User name for authenticating to your mail server.'), array( 'maxlength' => 255 ) );
		$Form->password_input( 'eblog_password', $Settings->get( 'eblog_password' ),15,T_('Password'), array( 'maxlength' => 255, 'note' => T_('Password for authenticating to your mail server.') ) );
		//TODO: have a drop down list of available blogs and categories
		$Form->text_input( 'eblog_default_category', $Settings->get( 'eblog_default_category' ), 5, T_('Default Category ID'), T_('By default emailed posts will have this category.'), array( 'maxlength' => 6 ) );
		$Form->text_input( 'eblog_subject_prefix', $Settings->get( 'eblog_subject_prefix' ), 15, T_('Subject Prefix'), T_('Email subject must start with this prefix to be imported.'), array( 'maxlength' => 255 ) );
		// eblog test links
		$getmailurl = $app_baseurl.'qp_srvc/getmail.php?test=';
		$Form->info_field(
			T_('Perform Server Test'),
			' <a id="eblog_test" target="_blank" href="'.$getmailurl.'1" onclick=\'return pop_up_window( "'.$getmailurl.'1", "getmail" )\'>[ ' . T_('connection') . ' ]</a>'
			.' <a id="eblog_test" target="_blank" href="'.$getmailurl.'2" onclick=\'return pop_up_window( "'.$getmailurl.'2", "getmail" )\'>[ ' . T_('messages') . ' ]</a>'
			.' <a id="eblog_test" target="_blank" href="'.$getmailurl.'3" onclick=\'return pop_up_window( "'.$getmailurl.'3", "getmail" )\'>[ ' . T_('verbose') . ' ]</a>',
			array() );
//		$Form->info_field ('','<a id="eblog_test_email" href="#" onclick=\'return pop_up_window( "' . $srvc_url . 'getmail.php?test=email", "getmail" )\'>' . T_('Test email') . '</a>',array());
		// special show / hide link
		$Form->info_field('', get_link_showhide( 'eblog_show_more','eblog_section_more', T_('Hide extra options'), T_('Show extra options...') ) );
		// TODO: provide Non-JS functionality
		echo '<div id="eblog_section_more" style="display:none">';
			$Form->checkbox( 'eblog_novalidatecert', $Settings->get( 'eblog_novalidatecert' ), T_('Do not validate certificate'), T_('Do not validate the certificate from the TLS/SSL server. Check this if you are using a self-signed certificate.') );
			$Form->checkbox( 'eblog_add_imgtag', $Settings->get( 'eblog_add_imgtag' ), T_('Add &lt;img&gt; tags'), T_('Display image attachments using &lt;img&gt; tags (instead of creating a link).'));
			$Form->checkbox( 'AutoBR', $Settings->get( 'AutoBR' ), T_('Email Auto-BR'), T_('Add &lt;BR /&gt; tags to mail posts.') );
			$Form->text_input( 'eblog_body_terminator', $Settings->get( 'eblog_body_terminator' ), 15, T_('Body Terminator'), T_('Starting from this string, everything will be ignored, including this string.'), array( 'maxlength' => 255 )  );
			$Form->checkbox_input( 'eblog_test_mode', $Settings->get( 'eblog_test_mode' ), T_('Test Mode'), array( 'note' => T_('Check to run Blog by Email in test mode.' ) ) );
			/* tblue> this isn't used/implemented at the moment
			$Form->checkbox_input( 'eblog_phonemail', $Settings->get( 'eblog_phonemail' ), T_('Phone Email *'),
				array( 'note' => 'Some mobile phone email services will send identical subject &amp; content on the same line. If you use such a service, check this option, and indicate a separator string when you compose your message, you\'ll type your subject then the separator string then you type your login:password, then the separator, then content.' ) );
			$Form->text_input( 'eblog_phonemail_separator', $Settings->get( 'eblog_phonemail_separator' ), 15, T_('Phonemail Separator'), '',
												array( 'maxlength' => 255 ) );*/
		echo '</div>';
	echo '</div>';
$Form->end_fieldset();

// --------------------------------------------

$Form->begin_fieldset( get_manual_link('categories-global-settings').T_('Categories'), array( 'id'=>'categories') );
	$Form->checkbox_input( 'allow_moving_chapters', $Settings->get( 'allow_moving_chapters' ), T_('Allow moving categories'), array( 'note' => T_('Check to allow moving categories accross blogs. (Caution: can break pre-existing permalinks!)' ) ) );
	$Form->radio_input( 'chapter_ordering', $Settings->get( 'chapter_ordering' ), array(
					array( 'value'=>'alpha', 'label'=>T_('Alphabetical') ),
					array( 'value'=>'manual', 'label'=>T_('Manual ') ),
			 ), T_('Ordering of categories') );
$Form->end_fieldset();

// --------------------------------------------

$GroupCache = & get_Cache( 'GroupCache' );

$Form->begin_fieldset( T_('Default user permissions') );
	$Form->checkbox( 'newusers_canregister', $Settings->get( 'newusers_canregister' ), T_('New users can register'), T_('Check to allow new users to register themselves.' ) );
	$Form->select_object( 'newusers_grp_ID', $Settings->get( 'newusers_grp_ID' ), $GroupCache, T_('Group for new users'), T_('Groups determine user roles and permissions.') );
	$Form->text_input( 'newusers_level', $Settings->get( 'newusers_level' ), 1, T_('Level for new users'), T_('Levels determine hierarchy of users in blogs.' ), array( 'maxlength'=>1, 'required'=>true ) );
$Form->end_fieldset();

// --------------------------------------------

$BlogCache = & get_Cache( 'BlogCache' );

$Form->begin_fieldset( T_('Display options') );
	$Form->select_input_object( 'default_blog_ID', $Settings->get( 'default_blog_ID' ), $BlogCache, T_('Default blog to display'), array(
			'note' => T_('This blog will be displayed on index.php.').' <a href="'.$dispatcher.'?ctrl=collections&action=new">'.T_('Create new blog').' &raquo;</a>',
			'allow_none' => true,
			'class' => '',
			'loop_object_method' => 'get_maxlen_name',
			'onchange' => '' )  );
$Form->end_fieldset();

// --------------------------------------------

$Form->begin_fieldset( T_('Email validation') );
	$Form->checkbox( 'newusers_mustvalidate', $Settings->get( 'newusers_mustvalidate' ), T_('New users must validate email'), T_('Check to require users to validate their email by clicking a link sent to them.' ) );
	$Form->checkbox( 'newusers_revalidate_emailchg', $Settings->get( 'newusers_revalidate_emailchg' ), T_('Validate email changes'), T_('Check to require users to re-validate when they change their email address.' ) );
$Form->end_fieldset();

// --------------------------------------------

// online help links "file-manager" and "online-help" need to be combined into "features"
$Form->begin_fieldset( get_manual_link('features').T_('Features') );
	$Form->checkbox_input( 'fm_enabled', $Settings->get( 'fm_enabled' ), T_('Enable filemanager'), array( 'note' => T_('Check to enable the Filemanager.' ) ) );
	$Form->checkbox_input( 'general_cache_enabled', $Settings->get( 'general_cache_enabled' ), T_('Enable general cache'), array( 'note'=>T_('Cache rendered pages that are not controlled by a template. See Blog Settings for template output caching.') ) );
	$Form->checkbox_input( 'webhelp_enabled', $Settings->get( 'webhelp_enabled' ), T_('Online Help links'), array( 'note' => T_('Online help links provide context sensitive help to certain features.' ) ) );
$Form->end_fieldset();

// --------------------------------------------

$Form->begin_fieldset( get_manual_link('hit-session-logging').T_('Hit & session logging') );
	$Form->checklist( array(
			array( 'log_public_hits', 1, T_('on every public page'), $Settings->get( 'log_public_hits' ) ),
			array( 'log_admin_hits', 1, T_('on every admin page'), $Settings->get( 'log_admin_hits' ) ) ),
		'log_hits', T_('Log hits') );
	// TODO: draw a warning sign if set to off
	$Form->radio_input( 'auto_prune_stats_mode', $Settings->get( 'auto_prune_stats_mode' ), array(
			array(
				'value'=>'off',
				'label'=>T_('Off'),
				'note'=>T_('Not recommended! Your database will grow very large!'),
				'onclick'=>'jQuery("#auto_prune_stats_container").hide();' ),
			array(
				'value'=>'page',
				'label'=>T_('On every page'),
				'note'=>T_('This is guaranteed to work but uses extra resources with every page displayed.'),
				'onclick'=>'jQuery("#auto_prune_stats_container").show();' ),
			array(
				'value'=>'cron',
				'label'=>T_('With a scheduled job'),
				'note'=>T_('Recommended if you have your scheduled jobs properly set up.'), 'onclick'=>'jQuery("#auto_prune_stats_container").show();' ) ),
		T_('Auto pruning'),
		array( 'note' => T_('Note: Even if you don\'t log hits, you still need to prune sessions!'),
		'lines' => true ) );
	echo '<div id="auto_prune_stats_container">';
	$Form->text_input( 'auto_prune_stats', $Settings->get( 'auto_prune_stats' ), 5, T_('Prune after'), T_('days. How many days of hits & sessions do you want to keep in the database for stats?') );
	echo '</div>';
	if( $Settings->get( 'auto_prune_stats_mode' ) == 'off' )
	{ // hide the "days" input field, if mode set to off:
		echo '<script type="text/javascript">jQuery("#auto_prune_stats_container").hide();</script>';
	}
$Form->end_fieldset();

// --------------------------------------------

$Form->begin_fieldset( T_('Security options') );
	$Form->text_input( 'user_minpwdlen', (int)$Settings->get( 'user_minpwdlen' ), 2, T_('Minimum password length'), T_('characters.'), array( 'maxlength'=>2, 'required'=>true ) );
	$Form->checkbox_input( 'js_passwd_hashing', (bool)$Settings->get( 'js_passwd_hashing' ), T_('Login password hashing'), array( 'note'=>T_('Check to enable the login form to hash the password with Javascript before transmitting it. This provides extra security on non-SSL connections.')) );
$Form->end_fieldset();

// --------------------------------------------

$Form->begin_fieldset( T_('Timeouts') );
	// fp>TODO: enhance UI with a general Form method for Days:Hours:Minutes:Seconds
	$Form->text_input( 'timeout_sessions', $Settings->get( 'timeout_sessions' ), 9, T_('Session timeout'), T_('seconds. How long can a user stay inactive before automatic logout?'), array( 'required'=>true) );
	// fp>TODO: It may make sense to have a different (smaller) timeout for sessions with no logged user.
	// fp>This might reduce the size of the Sessions table. But this needs to be checked against the hit logging feature.
	$Form->text_input( 'reloadpage_timeout', (int)$Settings->get( 'reloadpage_timeout' ), 5,
								T_('Reload-page timeout'), T_('Time (in seconds) that must pass before a request to the same URI from the same IP and useragent is considered as a new hit.'), array( 'maxlength'=>5, 'required'=>true ) );
$Form->end_fieldset();

// --------------------------------------------

if( $current_User->check_perm( 'options', 'edit' ) )
{
	$Form->end_form( array(
			array( 'submit', 'submit', T_('Update'), 'SaveButton' ),
			array( 'reset', '', T_('Reset'), 'ResetButton' ),
			array( 'submit', 'submit[restore_defaults]', T_('Restore defaults'), 'ResetButton' ),
		) );
}
else
{
	$Form->end_form();
}

?>
