<?php
/**
 * This file implements Template tags for use with templates.
 *
 * This file is part of the Quam Plures project - {@link http://quamplures.net/}.
 * See also {@link https://launchpad.net/quam-plures}.
 *
 * @copyright (c) 2009 by the Quam Plures developers - {@link http://quamplures.net/}
 * @copyright (c)2003-2009 by Francois PLANQUE - {@link http://fplanque.net/}.
 * Parts of this file are copyright (c)2004-2005 by Daniel HAHLER - {@link http://thequod.de/contact}.
 *
 * @license http://quamplures.net/license.html GNU General Public License (GPL)
 *
 * {@internal Open Source relicensing agreement:
 * Daniel HAHLER grants Francois PLANQUE the right to license
 * Daniel HAHLER's contributions to this file and the b2evolution project
 * under any OSI approved OSS license (http://www.opensource.org/licenses/).
 * }}
 *
 * {@internal Below is a list of authors who have contributed to design/coding of this file: }}
 * @author blueyed: Daniel HAHLER.
 * @author fplanque: Francois PLANQUE.
 *
 * @package templates
 */
if( !defined('QP_MAIN_INIT') ) die( 'Please, do not access this page directly.' );


/**
 * Template tag. Initializes internal states for the most common template displays.
 *
 * For more specific template, this function should not be called and
 * equivalent code should be customized within the template.
 *
 * @param string What are we going to display. Most of the time the global $disp should be passed.
 */
function template_init( & $disp )
{
	/**
	 * @var Blog
	 */
	global $Blog;

	/**
	 * @var Item
	 */
	global $Item;

	/**
	 * @var Template
	 */
	global $Template;

	global $robots_index;
	global $seo_page_type;

	global $redir, $ReqHost, $ReqURI, $m, $w, $preview;

	global $Chapter;
	global $Debuglog;

	/**
	 * @var ItemList2
	 */
	global $MainList;

	/**
	 * This will give more detail when $disp == 'posts'; otherwise it will have the same content as $disp
	 * @var string
	 */
	global $disp_detail;

	if( empty($disp_detail) )
	{
		$disp_detail = $disp;
	}

	$Debuglog->add('template_init: '.$disp, 'template');

	// do inits depending on $disp value...
	switch( $disp )
	{
		case 'posts':
		case 'single':
		case 'page':
		case 'feedback-popup':
			// We need to load posts for this display:

			// Note: even if we request the same post as $Item above, the following will do more restrictions (dates, etc.)
			// Init the MainList object:
			init_MainList( $Blog->get_setting('posts_per_page') );
			break;
	}

	$current_disp = $disp;
	if(
			(
				$disp != 'posts'
				&& !empty( $MainList )
				&& ( $ffs = mainlist_get_item() )
				&& ( $bar = param( 'page', 'integer', 1, true ) )
				&& (
					( $ffs->split_pages() != 'hello world' )
					&& $bar > 1
					&& $bar > $ffs->pages
				)
			)
			|| ( ( $bar = param( 'page', 'integer', 1, true ) ) && $bar < 0 )
		)
	{
		$disp = '404';
		$disp_detail = '404-post-page-not-found';
	}

	if( !empty( $MainList )
			&& ( $foo = param( $MainList->page_param, 'integer', 1, true ) )
			&&
			(
				(
					$foo > 1 && $foo > $MainList->total_pages
				)
				||
				(
					$foo < 0
				)
			)
		)
	{
		$disp = '404';
		$disp_detail = '404-mainlist-page-not-found';
	}

	if( !empty( $MainList ) )
	{
		$MainList->restart();
	}

	if( $current_disp != $disp )
	{ // looks like we 404'd
		global $disp_handlers, $ads_current_template_path;
		// copy MainList
		$GLOBALS['404-MainList'] = $MainList;
		// unset MainList
		unset( $MainList );
		unset( $GLOBALS['MainList'] );
		if( !empty( $disp_handlers[ $disp ] ) && file_exists( $disp_handler = $ads_current_template_path.$disp_handlers[$disp] ) )
		{
			$Debuglog->add('blog_main: include '.rel_path_to_base($disp_handler).' (custom to this template)', 'template');
			template_include( $disp_handlers[$disp] );
			exit;
		}
		else
		{	// Use the default handler from the templates dir:
			$Debuglog->add('blog_main: include '.rel_path_to_base($ads_current_template_path.'index.main.php').' (default handler)', 'template');
			template_include( 'index.main.php');
			exit;
		}
	}

	// SEO stuff:
	$seo_page_type = NULL;
	switch( $disp )
	{
		// CONTENT PAGES:
		case 'single':
		case 'page':
			if( $disp == 'single' )
			{
				$seo_page_type = 'Single post page';
			}
			else
			{
				$seo_page_type = '"Page" page';
			}

			// Check if the post has 'redirected' status:
			if( ! $preview && $Item->status == 'redirected' && $redir == 'yes' )
			{	// $redir=no here allows to force a 'single post' URL for commenting
				// Redirect to the URL specified in the post:
				$Debuglog->add( 'Redirecting to post URL ['.$Item->url.'].' );
				header_redirect( $Item->url, true );
			}

			// Check if we want to redirect to a canonical URL for the post
			// Please document encountered problems.
			if( ! $preview
					&& (( $Blog->get_setting( 'canonical_item_urls' ) && $redir == 'yes' )
								|| $Blog->get_setting( 'relcanonical_item_urls' ) ) )
			{	// We want to redirect to the Item's canonical URL:

				$canonical_url = $Item->get_permanent_url( '', '', '&' );
				if( preg_match( '|[&?](page=\d+)|', $ReqURI, $page_param ) )
				{	// A certain post page has been requested, keep only this param and discard all others:
					$canonical_url = url_add_param( $canonical_url, $page_param[1], '&' );
				}

				if( ! is_same_url( $ReqHost.$ReqURI, $canonical_url) )
				{	// The requested URL does not look like the canonical URL for this post...
					if( $Blog->get_setting( 'canonical_item_urls' ) && $redir == 'yes' )
					{	// REDIRECT TO THE CANONICAL URL:
						$Debuglog->add( 'Redirecting to canonical URL ['.$canonical_url.'].' );
						header_redirect( $canonical_url, true );
					}
					else
					{	// Use rel="canoncial":
						add_headline( '<link rel="canonical" href="'.$canonical_url.'" />' );
					}
					// EXITED.
				}
			}

			if( ! $MainList->result_num_rows )
			{	// There is nothing to display for this page, don't index it!
				$robots_index = false;
			}
			break;

		case 'posts':
			// Get list of active filters:
			$active_filters = $MainList->get_active_filters();

			if( !empty($active_filters) )
			{	// The current page is being filtered...

				if( array_diff( $active_filters, array( 'page' ) ) == array() )
				{ // This is just a follow "paged" page
					$disp_detail = 'posts-next';
					$seo_page_type = 'Next page';
					if( $Blog->get_setting( 'paged_noindex' ) )
					{	// We prefer robots not to index category pages:
						$robots_index = false;
					}
				}
				elseif( array_diff( $active_filters, array( 'cat_array', 'cat_modifier', 'cat_focus', 'posts', 'page' ) ) == array() )
				{ // This is a category page
					$disp_detail = 'posts-cat';
					$seo_page_type = 'Category page';
					if( $Blog->get_setting( 'chapter_noindex' ) )
					{	// We prefer robots not to index category pages:
						$robots_index = false;
					}

					global $cat, $catsel;
					if( empty( $catsel ) && preg_match( '[0-9]+', $cat ) )
					{	// We are on a single cat page:
						// NOTE: we must have selected EXACTLY ONE CATEGORY through the cat parameter
						// BUT: - this can resolved to including children
						//      - selecting exactly one cat through catsel[] is NOT OK since not equivalent (will exclude children)
						// echo 'SINGLE CAT PAGE';
						if( ( $Blog->get_setting( 'canonical_cat_urls' ) && $redir == 'yes' )
							|| $Blog->get_setting( 'relcanonical_cat_urls' ) )
						{ // Check if the URL was canonical:
							if( !isset( $Chapter ) )
							{
								$ChapterCache = & get_Cache( 'ChapterCache' );
								/**
								 * @var Chapter
								 */
								$Chapter = & $ChapterCache->get_by_ID( $MainList->filters['cat_array'][0], false );
							}
							if( $Chapter )
							{
								$canonical_url = $Chapter->get_permanent_url( NULL, NULL, $MainList->get_active_filter('page'), NULL, '&' );
								if( ! is_same_url($ReqHost.$ReqURI, $canonical_url) )
								{	// fp> TODO: we're going to lose the additional params, it would be better to keep them...
									// fp> what additional params actually?
									if( $Blog->get_setting( 'canonical_cat_urls' ) && $redir == 'yes' )
									{	// REDIRECT TO THE CANONICAL URL:
										header_redirect( $canonical_url, true );
									}
									else
									{	// Use rel="canoncial":
										add_headline( '<link rel="canonical" href="'.$canonical_url.'" />' );
									}
								}
							}
						}
					}
				}
				elseif( array_diff( $active_filters, array( 'tags', 'posts', 'page' ) ) == array() )
				{ // This is a tag page
					$disp_detail = 'posts-tag';
					$seo_page_type = 'Tag page';
					if( $Blog->get_setting( 'tag_noindex' ) )
					{	// We prefer robots not to index tag pages:
						$robots_index = false;
					}

					if( ( $Blog->get_setting( 'canonical_tag_urls' ) && $redir == 'yes' )
							|| $Blog->get_setting( 'relcanonical_tag_urls' ) )
					{ // Check if the URL was canonical:
						$canonical_url = $Blog->gen_tag_url( $MainList->get_active_filter('tags'), $MainList->get_active_filter('page'), '&' );
						if( ! is_same_url($ReqHost.$ReqURI, $canonical_url) )
						{
							if( $Blog->get_setting( 'canonical_tag_urls' ) && $redir == 'yes' )
							{	// REDIRECT TO THE CANONICAL URL:
								header_redirect( $canonical_url, true );
							}
							else
							{	// Use rel="canoncial":
								add_headline( '<link rel="canonical" href="'.$canonical_url.'" />' );
							}
						}
					}
				}
				elseif( array_diff( $active_filters, array( 'ymdhms', 'week', 'posts', 'page' ) ) == array() ) // fp> added 'posts' 2009-05-19; can't remember why it's not in there
				{ // This is an archive page
					// echo 'archive page';
					$disp_detail = 'posts-date';
					$seo_page_type = 'Date archive page';

					if( ($Blog->get_setting( 'canonical_archive_urls' ) && $redir == 'yes' )
							|| $Blog->get_setting( 'relcanonical_archive_urls' ) )
					{ // Check if the URL was canonical:
						$canonical_url =  $Blog->gen_archive_url( substr( $m, 0, 4 ), substr( $m, 4, 2 ), substr( $m, 6, 2 ), $w, '&', $MainList->get_active_filter('page') );
						if( ! is_same_url($ReqHost.$ReqURI, $canonical_url) )
						{
							if( $Blog->get_setting( 'canonical_archive_urls' ) && $redir == 'yes' )
							{	// REDIRECT TO THE CANONICAL URL:
								header_redirect( $canonical_url, true );
							}
							else
							{	// Use rel="canoncial":
								add_headline( '<link rel="canonical" href="'.$canonical_url.'" />' );
							}
						}
					}

					if( $Blog->get_setting( 'archive_noindex' ) )
					{	// We prefer robots not to index archive pages:
						$robots_index = false;
					}
				}
				else
				{	// Other filtered pages:
					// pre_dump( $active_filters );
					$disp_detail = 'posts-filtered';
					$seo_page_type = 'Other filtered page';
					if( $Blog->get_setting( 'filtered_noindex' ) )
					{	// We prefer robots not to index other filtered pages:
						$robots_index = false;
					}
				}
			}
			else
			{	// This is the default blog page
				$disp_detail = 'posts-default';
				$seo_page_type = 'Default page';
				if( ($Blog->get_setting( 'canonical_homepage' ) && $redir == 'yes' )
						|| $Blog->get_setting( 'relcanonical_homepage' ) )
				{ // Check if the URL was canonical:
					$canonical_url = $Blog->gen_blogurl();
					if( ! is_same_url($ReqHost.$ReqURI, $canonical_url) )
					{
						if( $Blog->get_setting( 'canonical_homepage' ) && $redir == 'yes' )
						{	// REDIRECT TO THE CANONICAL URL:
							header_redirect( $canonical_url, true );
						}
						else
						{	// Use rel="canoncial":
							add_headline( '<link rel="canonical" href="'.$canonical_url.'" />' );
						}
					}
				}

				if( $Blog->get_setting( 'default_noindex' ) )
				{	// We prefer robots not to index archive pages:
					$robots_index = false;
				}
			}

			break;

		// SPECIAL FEATURE PAGES:
		case 'feedback-popup':
			$seo_page_type = 'Comment popup';
			if( $Blog->get_setting( $disp.'_noindex' ) )
			{	// We prefer robots not to index these pages:
				$robots_index = false;
			}
			break;

		case 'arcdir':
			$seo_page_type = 'Date archive directory';
			if( $Blog->get_setting( $disp.'_noindex' ) )
			{	// We prefer robots not to index these pages:
				$robots_index = false;
			}
			break;

		case 'catdir':
			$seo_page_type = 'Category directory';
			if( $Blog->get_setting( $disp.'_noindex' ) )
			{	// We prefer robots not to index these pages:
				$robots_index = false;
			}
			break;

		case 'msgform':
			$seo_page_type = 'Contact form';
			if( $Blog->get_setting( $disp.'_noindex' ) )
			{	// We prefer robots not to index these pages:
				$robots_index = false;
			}
			break;

		case 'credits':
		case 'profile':
		case 'subs':
			$seo_page_type = 'Special feature page';
			if( $Blog->get_setting( 'special_noindex' ) )
			{	// We prefer robots not to index these pages:
				$robots_index = false;
			}
			break;

		case '404':
			// We have a 404 unresolved content error
			// How do we want do deal with it?
			template_404_header();
			// This MAY or MAY not have exited -- will exit on 30x redirect, otherwise will return here.
			// Just in case some dumb robot needs extra directives on this:
			$robots_index = false;
			break;
	}

	// Initialize displaying....
	$Template->display_init();
}


/**
 * Tells if we are on the default blog page
 *
 * @return boolean
 */
function is_default_page()
{
	global $disp_detail;
	return ($disp_detail == 'posts-default' );
}


/**
 * T-tag: Include a sub-template at the current position
 *
 * @todo EdB: $disp_handler is very nice :)
 */
function template_include( $template_name, $params = array() )
{
	global $templates_path, $ads_current_template_path, $disp;

	// Globals that may be needed by the template:
	global $Blog, $MainList, $Item;
	global $Plugins, $Template;
	global $current_User, $Hit, $Session, $Settings;
	global $template_url, $srvc_url, $srvc_url_sensitive;

	if( $template_name == '$disp$' )
	{ // This is a special case.
		// We are going to include a template based on $disp:

		// Default display handlers:
		$disp_handlers = array(
				'disp_404'            => '_404_not_found.disp.php',
				'disp_arcdir'         => '_arcdir.disp.php',
				'disp_catdir'         => '_catdir.disp.php',
				'disp_comments'       => '_comments.disp.php',
				'disp_credits'        => '_credits.disp.php',
				'disp_feedback-popup' => '_feedback_popup.disp.php',
				'disp_mediaidx'       => '_mediaidx.disp.php',
				'disp_msgform'        => '_msgform.disp.php',
				'disp_page'           => '_page.disp.php',
				'disp_posts'          => '_posts.disp.php',
				'disp_profile'        => '_profile.disp.php',
				'disp_single'         => '_single.disp.php',
				'disp_subs'           => '_subs.disp.php',
				'disp_user'           => '_user.disp.php',
			);

		// allow template overrides
		$disp_handlers = array_merge( $disp_handlers, $params );

		if( !isset( $disp_handlers['disp_'.$disp] ) )
		{
			printf( '<div class="template_error">Unhandled disp type [%s]</div>', $disp );
			return;
		}

		$template_name = $disp_handlers['disp_'.$disp];

		if( empty( $template_name ) )
		{	// The caller asked not to display this handler
			return;
		}
	}

	$disp_handled = false;
	if( file_exists( $ads_current_template_path.$template_name ) )
	{	// The template has a customized handler, use that one instead:
		global $Debuglog;
		$file = $ads_current_template_path.$template_name;
		$Debuglog->add('template_include ('.($Item ? 'Item #'.$Item->ID : '-').'): '.rel_path_to_base($file), 'templates');
		require $file;
	}
	elseif( file_exists( $templates_path.$template_name ) )
	{	// Use the default template:
		global $Debuglog;
		$file = $templates_path.$template_name;
		$Debuglog->add('template_include ('.($Item ? 'Item #'.$Item->ID : '-').'): '.rel_path_to_base($file), 'templates');
		require $file;
	}
	else
	{ // nothing handled the disp mode
		printf( '<div class="template_error">Sub template [%s] not found.</div>', $template_name );
		if( !empty($current_User) && $current_User->level == 10 )
		{
			printf( '<div class="template_error">User level 10 help info: [%s]</div>', $ads_current_template_path.$template_name );
		}
	}
}


/**
 * T-Tag: Outputs the "base href" tag for the current template.
 *
 * This is needed for relative css and img includes.
 * @uses base_tag()
 */
function template_base_tag()
{
	global $templates_url, $template, $Blog, $disp;

	if( ! empty( $template ) )
	{
		$base_href = $templates_url.$template.'/';
	}
	else
	{ // No template used:
		if( ! empty( $Blog ) )
		{
			$base_href = $Blog->gen_baseurl();
		}
		else
		{
			global $app_baseurl;
			$base_href = $app_baseurl;
		}
	}

	$target = NULL;
	if( !empty($disp) && strpos( $disp, '-popup' ) )
	{	// We are (normally) displaying in a popup window, we need most links to open a new window!
		$target = '_blank';
	}

	base_tag( $base_href, $target );
}


/**
 * T-Tag: Outputs the "meta name description" tag
 *
 * Note for future mods: we do NOT want to repeat identical content on multiple pages.
 */
function template_description_tag()
{
	global $Blog, $disp, $disp_detail, $MainList, $Chapter;

	$r = '';

	if( is_default_page() )
	{
		if( !empty($Blog) )
		{	// Description for the blog:
			$r = $Blog->get('shortdesc');
		}
	}
	elseif( $disp_detail == 'posts-cat' )
	{
		if( $Blog->get_setting( 'categories_meta_description') )
		{
			$r = $Chapter->get( 'description' );
		}
	}
	elseif( in_array( $disp, array( 'single', 'page' ) ) )
	{	// custom desc for the current single post:
		$Item = & $MainList->get_by_idx( 0 );
		if( is_null( $Item ) )
		{	// This is not an object (happens on an invalid request):
			return;
		}

		$r = $Item->get_metadesc();

		if( empty( $r )&& $Blog->get_setting( 'excerpts_meta_description' ) )
		{	// Fall back to excerpt for the current single post:
			$r = preg_replace( '|[\r\n]+|', '', $Item->get('excerpt') );
		}
	}

	if( !empty($r) )
	{
		echo '<meta name="description" content="'.format_to_output( $r, 'htmlattr' )."\" />\n";
	}
}


/**
 * T-Tag: Outputs the "meta name keywords" tag
 *
 * Note for future mods: we do NOT want to repeat identical content on multiple pages.
 */
function template_keywords_tag()
{
	global $Blog, $disp, $MainList;

	$r = '';

	if( is_default_page() )
	{
		if( !empty($Blog) )
		{
			$r = $Blog->get('keywords');
		}
	}
	elseif( in_array( $disp, array( 'single', 'page' ) ) )
	{	// custom keywords for the current single post:
		$Item = & $MainList->get_by_idx( 0 );
		if( is_null( $Item ) )
		{	// This is not an object (happens on an invalid request):
			return;
		}

		$r = $Item->get_metakeywords();

		/* fp> TODO:
		if( empty( $r ) && $Blog->get_setting( 'tags_meta_keywords' ) )
		{	// Fall back to tags for the current single post:

		}
		*/
	}

	if( !empty($r) )
	{
		echo '<meta name="keywords" content="'.format_to_output( $r, 'htmlattr' )."\" />\n";
	}
}


/**
 * Sends the desired HTTP response header in case of a "404".
 */
function template_404_header()
{
	global $Blog;

	// We have a 404 unresolved content error
	// How do we want do deal with it?
	switch( $resp_code = $Blog->get_setting( '404_response' ) )
	{
		case '404':
			header('HTTP/1.0 404 Not Found');
			break;

		case '410':
			header('HTTP/1.0 410 Gone');
			break;

		case '301':
		case '302':
		case '303':
			// Redirect to home page:
			header_redirect( $Blog->get('url'), intval($resp_code) );
			// THIS WILL EXIT!
			break;

		default:
			// Will result in a 200 OK
	}
}


/**
 * Obsolete Template Tag
 *
 * @todo EdB: this is obsolete from way back. The only thing
 * it does is help an old skin act like a new template
 */
function template_content_header( $type = 'text/html' )
{
	header_content_type( $type );
}


/**
 * T-Tag: Outputs the "meta http-equiv Content-Type" tag
 *
 * @param string content-type; override for RSS feeds
 */
function template_content_meta( $type = 'text/html' )
{
	global $io_charset;

	echo '<meta http-equiv="Content-Type" content="'.$type.'; charset='.$io_charset.'" />'."\n";
}


/**
 * T-tag: Display a Widget
 *
 * This load the widget class, instantiates it, and displays it.
 *
 * @param array
 * @uses ComponentWidget::display()
 * @uses ComponentWidget::init_display()
 */
function template_widget( $params )
{
	if( empty( $params['widget'] ) )
	{
		echo 'No widget code provided!';
		return false;
	}

	$wiCache = get_Cache('WidgetCache');
	$widget_code = $params['widget'];
	unset( $params['widget'] );

	if( ! $wiCache->load_widget( $widget_code ) )
	{	// For some reason, that widget doesn't seem to exist... (any more?)
		echo "Invalid widget code provided [$widget_code]!";
		return false;
	}

	$widget_classname = $widget_code.'_Widget';

	/**
	 * @var ComponentWidget
	 */
	$Widget = new $widget_classname();	// COPY !!

	return $Widget->display( $params );
}


/**
 * T-tag: Display a container's widgets
 *
 * Param priorities: widget, container, defaults
 *
 * @uses Template::container()
 * @uses ComponentWidget::display()
 * @uses ComponentWidget::init_display()
 *
 * @param string
 * @param array
 */
function template_container( $sco_name, $params = array() )
{
	global $Template;

	$Template->container( $sco_name, $params );
}


/**
 * Install a template
 *
 * @todo do not install if template doesn't exist. Important for upgrade. Need to NOT fail if ZERO templates installed though :/
 *
 * @param string The folder name of the template to install.
 * @return Template|bool A Template object on success, false on failure.
 */
function & template_install( $template_folder )
{
	global $Messages;

	$TemplateCache = & get_cache( 'TemplateCache' );
	$Template = & $TemplateCache->new_obj( NULL, $template_folder );

	// Check whether credits are valid:
	$tpl_credits = $Template->get_template_credits();
	if( count( $tpl_credits ) > 3 )
	{	// Warn the user: This template could be "spammy".
		$Messages->add( T_( 'This template provides more than three linkbacks. '.
							'Beware of possible spam links.' ),
						'note' );
	}

	$error = false;

	foreach( $tpl_credits as $k => $v )
	{
		if( ( $missing = array_diff( array( 'pre', 'text', 'post', 'url', 'title' ),
				array_keys( $v ) ) ) )
		{	// Ooops, something's missing!
			$error = true;

			$Messages->add( sprintf(
					/* TRANS: 1st %s: Linkback name/array key. 2nd %s: Missing array keys (list). */
					T_( 'Linkback &laquo;%s&raquo; is missing the following keys: %s' ),
					htmlspecialchars( $k, ENT_QUOTES ),
					htmlspecialchars( implode( ', ', $missing ), ENT_QUOTES ) ),
				'error' );
		}
	}

	if( $error || ! $Template->install() )
	{
		$r = false;
		return $r;
	}

	return $Template;
}


/**
 * Checks if a template is provided by a plugin.
 *
 * Used by front-end.
 *
 * @uses Plugin::GetProvidedTemplates()
 * @return false|integer False in case no plugin provides the template or ID of the first plugin that provides it.
 */
function template_provided_by_plugin( $name )
{
	static $plugin_templates;
	if( ! isset($plugin_templates) || ! isset($plugin_templates[$name]) )
	{
		global $Plugins;

		$plugin_r = $Plugins->trigger_event_first_return('GetProvidedTemplates', NULL, array('in_array'=>$name));
		if( $plugin_r )
		{
			$plugin_templates[$name] = $plugin_r['plugin_ID'];
		}
		else
		{
			$plugin_templates[$name] = false;
		}
	}

	return $plugin_templates[$name];
}


/**
 * Checks if a template exists. This can either be a regular template directory
 * or can be in the list {@link Plugin::GetProvidedTemplates()}.
 *
 * Used by front-end.
 *
 * @param template name (directory name)
 * @return boolean true is exists, false if not
 */
function template_exists( $name, $filename = 'index.main.php' )
{
	global $templates_path;

	if( template_file_exists( $name, $filename ) )
	{
		return true;
	}

	// Check list provided by plugins:
	if( template_provided_by_plugin($name) )
	{
		return true;
	}

	return false;
}


/**
 * Checks if a specific file exists for a template.
 *
 * @param template name (directory name)
 * @param file name
 * @return boolean true is exists, false if not
 */
function template_file_exists( $name, $filename = 'index.main.php' )
{
	global $templates_path;

	if( is_readable( $templates_path.$name.'/'.$filename ) )
	{
		return true;
	}

	return false;
}


/**
 * Check if a template is installed.
 *
 * This can either be a regular template or a template provided by a plugin.
 *
 * @param Template name (directory name)
 * @return boolean True if the template is installed, false otherwise.
 */
function template_installed( $name )
{
	$TemplateCache = & get_Cache( 'TemplateCache' );

	if( template_provided_by_plugin( $name ) || $TemplateCache->get_by_folder( $name, false ) )
	{
		return true;
	}

	return false;
}


?>
