<?php
/**
 * This file implements the TemplateCache class.
 *
 * This file is part of Quam Plures - {@link http://quamplures.net/}
 * See also {@link https://launchpad.net/quam-plures}.
 *
 * @copyright (c) 2009 by the Quam Plures developers - {@link http://quamplures.net/}
 * @copyright (c)2003-2009 by Francois PLANQUE - {@link http://fplanque.net/}
 *
 * {@internal License choice
 * - If you have received this file as part of a package, please find the license.txt file in
 *   the same folder or the closest folder above for complete license terms.
 * - If you have received this file individually (e-g: from http://evocms.cvs.sourceforge.net/)
 *   then you must choose one of the following licenses before using the file:
 *   - GNU General Public License 2 (GPL) - http://www.opensource.org/licenses/gpl-license.php
 *   - Mozilla Public License 1.1 (MPL) - http://www.opensource.org/licenses/mozilla1.1.php
 * }}
 *
 * {@internal Open Source relicensing agreement:
 * }}
 *
 * @author fplanque: Francois PLANQUE
 *
 * @package templates
 */
if( !defined('QP_MAIN_INIT') ) die( 'Please, do not access this page directly.' );

load_class('_core/model/dataobjects/_dataobjectcache.class.php');

load_class( 'templates/model/_template.class.php' );

load_funcs( 'templates/_template.funcs.php' );

/**
 * Template Cache Class
 *
 * @package templates
 */
class TemplateCache extends DataObjectCache
{
	/**
	 * Cache by folder
	 * @var array
	 */
	var $cache_by_folder = array();

	var $loaded_types = array();


	/**
	 * Constructor
	 */
	function TemplateCache()
	{
		parent::DataObjectCache( 'Template', false, 'T_templates__template', 'template_', 'template_ID', 'template_name', NULL,
			/* TRANS: "None" select option */ T_('No template') );
	}


	/**
	 * Add object to cache, handling our own indices.
	 *
	 * @param Template
	 * @return boolean True on add, false if already existing.
	 */
	function add( & $Template )
	{
		$this->cache_by_folder[ $Template->folder ] = & $Template;

		return parent::add( $Template );
	}


	/**
	 * Get an object from cache by its folder name.
	 *
	 * Load the object into cache, if necessary.
	 *
	 * This is used to get a template for an RSS/Aom type; also to check if a template is installed.
	 *
	 * @param string folder name of object to load
	 * @param boolean false if you want to return false on error
	 * @return Template A Template object on success, false on failure (may also halt!)
	 */
	function & get_by_folder( $req_folder, $halt_on_error = true )
	{
		global $DB, $Debuglog;

		if( isset($this->cache_by_folder[$req_folder]) )
		{
			return $this->cache_by_folder[$req_folder];
		}

		// Load just the requested object:
		$Debuglog->add( "Loading <strong>$this->objtype($req_folder)</strong> into cache", 'dataobjects' );
		$sql = "
				SELECT *
				  FROM $this->dbtablename
				 WHERE template_folder = ".$DB->quote($req_folder);
		$row = $DB->get_row( $sql );

		if( empty( $row ) )
		{ // Requested object does not exist
			if( $halt_on_error ) debug_die( "Requested $this->objtype does not exist!" );
			$r = false;
			return $r;
		}

		$Template = new Template( $row ); // COPY!
		$this->add( $Template );

		return $Template;
	}


	/**
	 * Load the cache by type
	 *
	 * @param string
 	 */
	function load_by_type( $type )
	{
		/**
		 * @var DB
		 */
		global $DB;
		global $Debuglog;

		if( $this->all_loaded || !empty($this->loaded_types[$type]) )
		{ // Already loaded
			return false;
		}

		$Debuglog->add( get_class($this).' - Loading <strong>'.$this->objtype.'('.$type.')</strong> into cache', 'dataobjects' );
		$sql = 'SELECT *
							FROM T_templates__template
						 WHERE template_type = '.$DB->quote($type).'
						 ORDER BY template_name';

		foreach( $DB->get_results( $sql, OBJECT, 'Loading Templates('.$type.') into cache' ) as $row )
		{
			// Instantiate a custom object
			$this->instantiate( $row );
		}

		$this->loaded_types[$type] = true;

		return true;
	}


	/**
	 * Instanciate a new object within this cache
	 */
	function & new_obj( $row = NULL, $template_folder = NULL )
	{
		if( is_null($template_folder) )
		{	// This happens when using the default template
			$template_folder = $row->template_folder;
		}

		// Check if we have a custom class derived from Template:
		if( template_file_exists( $template_folder, '_template.class.php' ) )
		{
			global $templates_path;
			require_once( $templates_path.$template_folder.'/_template.class.php' );
			$objtype = $template_folder.'_Template';
			if( ! class_exists($objtype) )
			{
				debug_die( 'There seems to be a _template.class.php file in the template directory ['.$template_folder.'], but it does not contain a properly named class. Expected class name is: '.$objtype );
			}
		}
		else
		{
			$objtype = 'Template';
		}

		// Instantiate a custom object
		$obj = new $objtype( $row, $template_folder ); // COPY !!

		return $obj;
	}

}

?>