<?php
/**
 * This file implements the Widget class.
 *
 * This file is part of Quam Plures - {@link http://quamplures.net/}
 * See also {@link https://launchpad.net/quam-plures}.
 *
 * @copyright (c) 2009 by the Quam Plures developers - {@link http://quamplures.net/}
 * @copyright (c)2003-2009 by Francois PLANQUE - {@link http://fplanque.net/}
 *
 * {@internal License choice
 * If you have received this file as part of a package, please find the license.txt file in
 * the same folder or the closest folder above for complete license terms.
 * If you have received this file individually (e-g: from http://evocms.cvs.sourceforge.net/)
 * then you must choose one of the following licenses before using the file:
 *  - GNU General Public License 2 (GPL) - http://www.opensource.org/licenses/gpl-license.php
 *  - Mozilla Public License 1.1 (MPL) - http://www.opensource.org/licenses/mozilla1.1.php
 * }}
 *
 * {@internal Below is a list of authors who have contributed to design/coding of this file: }}
 * @author fplanque: Francois PLANQUE.
 *
 * @package widgets
 */
if( !defined('QP_MAIN_INIT') ) die( 'Please, do not access this page directly.' );

/**
 * ComponentWidget Class
 *
 * A ComponentWidget is a displayable entity that can be placed into a Container on a web page.
 *
 * @package widgets
 */
class ComponentWidget extends DataObject
{
	var $coll_ID;
	/**
	 * Container name
	 */
	var $sco_name;
	var $order;
	/**
	 * @var string Type of the widget ("widget" or "plugin")
	 */
	var $type;
	var $code;
	var $params;

	var $widget_name;
	var $widget_title;

	/**
	 * Indicates whether the widget is enabled.
	 *
	 * @var boolean
	 */
	var $enabled;

	/**
	 * Array of params which have been customized for this widget instance
	 *
	 * This is saved to the DB as a serialized string ($params)
	 */
	var $param_array = NULL;

	/**
	 * Array of params used during display()
	 */
	var $disp_params;

	/**
	 * Lazy instantiated
	 * (false if this Widget is not handled by a Plugin)
	 * @see get_Plugin()
	 * @var Plugin
	 */
	var $Plugin;


	/**
	 * The translations keyed by locale. They get loaded through include() of _global.php.
	 * @see ComponentWidget::T_()
	 * @var array
	 */
	var $_trans = array();

	/**
	 * Has the global po/php/_global.php file (where translation for
	 * all languages can be put into) been loaded?
	 *
	 * @var boolean
	 */
	var $_trans_loaded_global = false;


	/**
	 * Constructor
	 *
	 * @param object data row from db
	 */
	function ComponentWidget( $db_row = NULL, $type = 'widget', $code = NULL )
	{
		// Call parent constructor:
		parent::DataObject( 'T_widget', 'wi_', 'wi_ID' );

		if( is_null($db_row) )
		{	// We are creating an object here:
			// Using parent:: instead of $this-> in order to fix http://forums.b2evolution.net//viewtopic.php?p=94778
			parent::set( 'type', $type );
			parent::set( 'code', $code );
		}
		else
		{	// We are loading an object:
			$this->ID       = $db_row->wi_ID;
			$this->coll_ID  = $db_row->wi_coll_ID;
			$this->sco_name = $db_row->wi_sco_name;
			$this->type     = $db_row->wi_type;
			$this->code     = $db_row->wi_code;
			$this->params   = $db_row->wi_params;
			$this->order    = $db_row->wi_order;
			$this->enabled  = $db_row->wi_enabled;
		}
	}


	/**
	 * Get ref to Plugin handling this Widget
	 *
	 * @return Plugin
	 */
	function & get_Plugin()
	{
		global $Plugins;

		if( is_null( $this->Plugin ) )
		{
			if( $this->type != 'plugin' )
			{
				$this->Plugin = false;
			}
			else
			{
				$this->Plugin = & $Plugins->get_by_code( $this->code );
			}
		}

		return $this->Plugin;
	}


	/**
	 * Load params
	 */
	function load_from_Request()
	{
		load_funcs('plugins/_plugin.funcs.php');

		// Loop through all widget params:
		foreach( $this->get_param_definitions( array('for_editing'=>true) ) as $parname => $parmeta )
		{
			autoform_set_param_from_request( $parname, $parmeta, $this, 'Widget' );
		}
	}


	/**
	 * Get name of widget
	 *
	 * Should be overriden by core widgets
	 */
	function get_name()
	{
		if( $this->widget_name )
		{ // we have a name
			$name = $this->widget_name;
		}
		else
		{ // we don't have a name
			if( $this->type == 'plugin' )
			{
				// Make sure Plugin is loaded:
				if( $this->get_Plugin() )
				{
					$name = $this->Plugin->name;
				}
				else
				{
					$name = T_('Inactive / Uninstalled plugin');
				}
			}
			else
			{ // it's a widget
				$name = T_('Unknown widget');
			}
		}

		if( $this->disp_params['widget_name'] && $name != $this->disp_params['widget_name'] )
		{ // user has renamed us
			$name .= ' : '.$this->disp_params['widget_name'];
		}

		return $name;
	}


	/**
	 * Get a very short desc. Used in the widget list.
	 *
	 * MAY be overriden by core widgets. Example: menu link widget.
	 */
	function get_short_desc()
	{
		return $this->get_name();
	}


	/**
	 * Get a clean description to display in the widget list
	 */
	function get_desc_for_list()
	{
		$name = $this->get_name();

		if( $this->type == 'plugin' )
		{
			return '<strong>'.$name.'</strong> ('.T_('Plugin').')';
		}

		$short_desc = $this->get_short_desc();

		if( $name == $short_desc || empty($short_desc) )
		{
			return '<strong>'.$name.'</strong>';
		}

		return '<strong>'.$short_desc.'</strong> ('.$name.')';
	}


	/**
	 * Get desc of widget
	 *
	 * Should be overriden by core widgets
	 */
	function get_desc()
	{
		if( $this->type == 'plugin' )
		{
			// Make sure Plugin is loaded:
			if( $this->get_Plugin() )
			{
				return $this->Plugin->short_desc;
			}
			return T_('Inactive / Uninstalled plugin');
		}

		return T_('Unknown');
	}


	/**
	 * Get definitions for editable params
	 *
	 * @see Plugin::GetDefaultSettings()
	 * @param local params like 'for_editing' => true
	 */
	function get_param_definitions( $params )
	{
		$r = array(
				'widget_name' => array(
					'label' => T_( 'Name' ),
					'size' => 20,
					'note' => T_( 'Displayed in the widget list.'),
					'defaultvalue' => $this->widget_name,
				),
				'widget_title' => array(
					'label' => T_( 'Title' ),
					'size' => 20,
					'note' => T_( 'Displayed in your template.'),
					'defaultvalue' => $this->widget_title,
				),
				'widget_css_class' => array(
					'label' => '<span class="dimmed">'.T_( 'CSS Class' ).'</span>',
					'size' => 20,
					'note' => T_( 'Replaces $wi_class$ in your templates containers.'),
				),
				'widget_ID' => array(
					'label' => '<span class="dimmed">'.T_( 'DOM ID' ).'</span>',
					'size' => 20,
					'note' => T_( 'Replaces $wi_ID$ in your templates containers.'),
				),
			);

		if( $this->type == 'plugin' )
		{
			// Make sure Plugin is loaded:
			if( $this->get_Plugin() )
			{
				$r = array_merge( $r, $this->Plugin->get_widget_param_definitions( $params ) );
			}
		}
		return $r;
	}


	/**
	 * Load param array
	 */
	function load_param_array()
	{
		if( is_null( $this->param_array ) )
		{	// Param array has not been loaded yet
			$this->param_array = @unserialize( $this->params );

			if( empty( $this->param_array ) )
			{	// No saved param values were found:
				$this->param_array = array();
			}
		}
	}


	/**
 	 * param value
 	 *
	 */
	function get_param( $parname )
	{
		$this->load_param_array();
		if( isset( $this->param_array[$parname] ) )
		{	// We have a value for this param:
			return $this->param_array[$parname];
		}

		// Try default values:
		$params = $this->get_param_definitions( NULL );
		if( isset( $params[$parname]['defaultvalue'] ) )
		{	// We ahve a default value:
			return $params[$parname]['defaultvalue'] ;
		}

		return NULL;
	}


	/**
	 * Set param value
	 *
	 * @param string parameter name
	 * @param mixed parameter value
	 * @return boolean true, if a value has been set; false if it has not changed
	 */
	function set( $parname, $parvalue )
	{
		$params = $this->get_param_definitions( NULL );

		if( isset( $params[$parname] ) )
		{	// This is a widget specific param:
			$this->param_array[$parname] = $parvalue;
			// This is what'll be saved to the DB:
			$this->set_param( 'params', 'string', serialize($this->param_array) );
			return;
		}

		switch( $parname )
		{
			default:
				return parent::set_param( $parname, 'string', $parvalue );
		}
	}


	/**
	 * Prepare display params
	 *
	 * Merge basic defaults < widget defaults < container params < DB params<br />
	 * When called with template_widget it falls back to: <br />
	 * basic defaults < widget defaults < calltime params < array()
	 *
	 * <code>
	 * $params = array_merge( array(
	 * 		// block-level params...
	 * 		'block_start' => '<div class="$wi_class$">',
	 * 		'block_end' => '</div>',
	 * 		'block_display_title' => true,
	 * 		'block_title_start' => '<h3>',
	 * 		'block_title_end' => '</h3>',
	 * 		// is this maybe sub-block params?
	 * 		'coll_start' => '<h4>',
	 * 		'coll_end' => '</h4>',
	 * 		'collist_start' => '',
	 * 		'collist_end' => '',
	 * 		// group and list params...
	 * 		'group_start' => '<ul>',
	 * 		'group_end' => '</ul>',
	 * 		'list_start' => '<ul>',
	 * 		'list_end' => '</ul>',
	 * 		// way too many item params...
	 * 		'item_start' => '<li>',
	 * 		'item_end' => '</li>',
	 * 		'item_text_start' => '',
	 * 		'item_text' => '%s',
	 * 		'item_text_end' => '',
	 * 		'item_selected_start' => '<li class="selected">',
	 * 		'item_selected_text' => '%s',
	 * 		'item_selected_end' => '</li>',
	 * 		'item_selected_text_start' => '',
	 * 		'item_selected_text_end' => '',
	 * 		// link params...
	 * 		'link_default_class' => 'default',
	 * 		'link_selected_class' => 'selected',
	 * 		'link_type' => 'canonic',		// 'canonic' | 'context' (context will regenrate URL injecting/replacing a single filter)
	 * 		// notes params...
	 * 		'notes_start' => '<div class="notes">',
	 * 		'notes_end' => '</div>',
	 * 		// thumb_size might be only with grid params but we need more image defaults
	 * 		'thumb_size' => 'crop-80x80',
	 * 		// this is probably a tag cloud param disguised as a real one
	 * 		'limit' => 100,
	 * 	), $widget_defaults, $params, $this->param_array );
	 * </code>
	 *
	 * @param array
	 */
	function init_display( $params )
	{
		global $admin_url;

		// Generate widget defaults array:
		$widget_defaults = array();
		$defs = $this->get_param_definitions( array() );
		foreach( $defs as $parname => $parmeta )
		{
			if( isset( $parmeta['defaultvalue'] ) )
			{
				$widget_defaults[ $parname ] = $parmeta['defaultvalue'];
			}
			else
			{
				$widget_defaults[ $parname ] = NULL;
			}
		}

		// Load DB configuration:
		$this->load_param_array();

		$params = array_merge( array(
					// block-level params...
					'block_start' => '<div class="$wi_class$">',
					'block_end' => '</div>',
					'block_display_title' => true,
					'block_title_start' => '<h3>',
					'block_title_end' => '</h3>',
					// is this maybe sub-block params?
					'coll_start' => '<h4>',
					'coll_end' => '</h4>',
					'collist_start' => '',
					'collist_end' => '',
					// group and list params...
					'group_start' => '<ul>',
					'group_end' => '</ul>',
					'list_start' => '<ul>',
					'list_end' => '</ul>',
					// way too many item params...
					'item_start' => '<li>',
					'item_end' => '</li>',
					'item_text_start' => '',
					'item_text' => '%s',
					'item_text_end' => '',
					'item_selected_start' => '<li class="selected">',
					'item_selected_text' => '%s',
					'item_selected_end' => '</li>',
					'item_selected_text_start' => '',
					'item_selected_text_end' => '',
					// link params...
					'link_default_class' => 'default',
					'link_selected_class' => 'selected',
					'link_type' => 'canonic',		// 'canonic' | 'context' (context will regenrate URL injecting/replacing a single filter)
					// notes params...
					'notes_start' => '<div class="notes">',
					'notes_end' => '</div>',
					// thumb size might be only with grid params but we need more image defaults
					'thumb_size' => 'crop-80x80',
					// 'thumb_size' => 'fit-160',
					// this is probably a tag cloud param disguised as a real one
					'limit' => 100,
				), $widget_defaults, $params, $this->param_array );

		if( false )
		{	// DEBUG:
			$params['block_start'] = '<div class="debug_widget"><div class="debug_widget_name"><span class="debug_container_action"><a href="'
						.$admin_url.'?ctrl=widgets&amp;action=edit&amp;wi_ID='.$this->ID.'">Edit</a></span>'.$this->get_name().'</div><div class="$wi_class$">';
			$params['block_end'] = '</div></div>';
		}

		// Customize params to the current widget:
		// add additional css classes if required
		$widget_css_class = 'widget_'.$this->type.'_'.$this->code.( empty( $params[ 'widget_css_class' ] ) ? '' : ' '.$params[ 'widget_css_class' ] );
		// add custom id if required, default to generic id for validation purposes
		$widget_ID = ( !empty($params[ 'widget_ID' ]) ? $params[ 'widget_ID' ] : 'widget_'.$this->type.'_'.$this->code.'_'.$this->ID );
		// replace the values
		$this->disp_params = str_replace( array( '$wi_ID$', '$wi_class$' ), array( $widget_ID, $widget_css_class ), $params );
	}


	/**
	 * Display the widget!
	 *
	 * Should be overriden by core widgets
	 *
	 * @uses ComponentWidget::init_display()
	 *
	 * @todo (legacy): fp> handle custom params for each widget
	 *
	 * @param array MUST contain at least the basic display params
	 */
	function display( $params )
	{
		global $Blog;
		global $Plugins;
		global $rsc_url;

		$this->init_display( $params );

		switch( $this->type )
		{
			case 'plugin':
				// Call plugin (will return false if Plugin is not enabled):
				if( $Plugins->call_by_code( $this->code, $this->disp_params ) )
				{
					return true;
				}
				// Plugin failed (happens when a plugin has been disabled for example):
				return false;
		}

		echo "Widget $this->type : $this->code did not provide a display() method! ";

		return false;
	}


	/**
	 * Note: a container can prevent display of titles with 'block_display_title'
	 * This is useful for the lists in the headers
	 * fp> I'm not sur if this param should be overridable by widgets themselves (priority problem)
	 * Maybe an "auto" setting.
	 */
	function disp_title( $title = NULL )
	{
		if( is_null($title) )
		{
			$title = $this->disp_params['widget_title'];
		}

		if( $this->disp_params['block_display_title'] && !empty( $title ) )
		{
			echo $this->disp_params['block_title_start'];
			echo format_to_output( $title );
			echo $this->disp_params['block_title_end'];
		}
	}


	/**
	 * Insert object into DB based on previously recorded changes.
	 *
	 * @return boolean true on success
	 */
	function dbinsert()
	{
		global $DB;

		if( $this->ID != 0 )
		{
			debug_die( 'Existing object cannot be inserted!' );
		}

		$DB->begin();

		$order_max = $DB->get_var(
			'SELECT MAX(wi_order)
				 FROM T_widget
				WHERE wi_coll_ID = '.$this->coll_ID.'
					AND wi_sco_name = '.$DB->quote($this->sco_name), 0, 0, 'Get current max order' );

		$this->set( 'order', $order_max+1 );

		$res = parent::dbinsert();

		$DB->commit();

		return $res;
	}


	/**
	 * Translate a given string, in the Widget's context.
	 *
	 * This means, that the translation is obtained from the Widget's "po/php" folder.
	 * @link [doclink] Localization#Extensions
	 *
	 * It uses the global/regular {@link T_()} function as a fallback.
	 *
	 * @param string The string (english), that should be translated
	 * @param string Requested locale ({@link $current_locale} gets used by default)
	 * @return string The translated string.
	 * @uses T_()
	 */
	function T_( $string, $req_locale = '' )
	{
		if( $this->type == 'plugin' )
		{ // use plugin translation function
			return $this->Plugin->T_( $string, $req_locale );
		}

		global $plugins_path,$Debuglog;

		$globalfile_path = $plugins_path.$this->code.'_widget/po/php/_global.php';
		$trans = & $this->_trans;

		// Load the global messages file, if existing:
		if( ! $this->_trans_loaded_global )
		{
			$this->_trans_loaded_global = true;

			if( file_exists( $globalfile_path ) && is_readable( $globalfile_path ) )
			{
				include_once $globalfile_path;
			}
			else
			{
				$Debuglog->add( 'Global messages file '.$globalfile_path.' does not exist or is not readable!', 'locale' );
			}
		}

		if ( ( $return = T_( $string, $req_locale, array(
								'ext_transarray' => & $this->_trans,
								'alt_basedir'    => $plugins_path.$this->code.'_widget/po/',
							) ) ) == $string )
		{	// Fallback to global translation file:
			return T_( $string, $req_locale );
		}
		return $return;
	}


	/**
	 * Translate and escape single quotes.
	 *
	 * This is to be used mainly for Javascript strings.
	 *
	 * @uses ComponentWidget::T_()
	 *
	 * @param string String to translate
	 * @param string Locale to use
	 * @return string The translated and escaped string.
	 */
	function TS_( $string, $req_locale = '' )
	{
		return str_replace( "'", "\\'", $this->T_( $string, $req_locale ) );
	}
}

?>
