<?php
/**
 * This file implements the GMcode plugin for Quam Plures
 *
 * GreyMatter style formatting
 *
 * Replaces GreyMatter markup in HTML (not XML).
 * @todo dh> Do not replace in tags, it matches e.g. the following for italic:
 *           """<img src="//url" /> [...] http://"""!
 *
 * Quam Plures - {@link http://quamplures.net/}
 * Released under GNU GPL License - {@link http://quamplures.net/license.html}
 * @copyright (c) 2009 by the Quam Plures developers - {@link http://quamplures.net/}
 * @copyright (c)2003-2009 by Francois PLANQUE - {@link http://fplanque.net/}
 *
 * @package plugins
 * @subpackage GMcode
 */
if( !defined('QP_MAIN_INIT') ) die( 'Please, do not access this page directly.' );


/**
 * @package plugins
 * @subpackage GMcode
 */
class gmcode_plugin extends Plugin
{
	var $apply_rendering = 'opt-out';
	var $code = 'gmcode';
	var $group = 'renderers';
	var $number_of_installs = 1;
	var $priority = 45;
	var $version = '0.1';

	// internal use vars...
	var $search = array(
			'# \*\* (.+?) \*\* #x',                // **bold**
			'# \x5c\x5c (.+?) \x5c\x5c #x',        // \\italics\\
			'# (?<!:) \x2f\x2f (.+?) \x2f\x2f #x', // //italics// (not preceded by : as in http://)
			'# __ (.+?) __ #x',                    // __underline__
			'/ \#\# (.+?) \#\# /x',                // ##tt##
			'/ %%
				( \s*? \n )?      # Eat optional blank line after %%%
				(.+?)
				( \n \s*? )?      # Eat optional blank line before %%%
				%%
			/sx'                                   // %%codeblock%%
		);
	var $replace = array(
			'<strong>$1</strong>',
			'<em>$1</em>',
			'<em>$1</em>',
			'<span style="text-decoration:underline">$1</span>',
			'<tt>$1</tt>',
			'<div class="codeblock"><pre><code>$2</code></pre></div>'
		);


	/**
	 * @see Plugin::PluginInit()
	 */
	function PluginInit( & $params )
	{
		$this->name = $this->T_('GM Code');
		$this->short_desc = $this->T_('GreyMatter style formatting');
		$this->long_desc = $this->T_('This plugin allows for GreyMatter style formatting such as **bold** or \\italics\\ or //italics// or __underline__ or ##tt## or %%codeblock%% in your blog post.');
	}


	/**
	 * @see Plugin::RenderItemAsHtml()
	 */
	function RenderItemAsHtml( & $params )
	{
		$content = & $params['data'];

		$content = callback_on_non_matching_blocks( $content, '~<[^>]*>~s', array($this, 'replace_callback') );

		return true;
	}


	/**
	 * Replace callback
	 */
	function replace_callback($text)
	{
		return preg_replace($this->search, $this->replace, $text);
	}


}

?>
