<?php
/**
 * This file implements the Menu link Widget class.
 *
 * This file is part of Quam Plures - {@link http://quamplures.net/}
 * See also {@link https://launchpad.net/quam-plures}.
 *
 * @copyright (c) 2009 by the Quam Plures developers - {@link http://quamplures.net/}
 * @copyright (c)2003-2009 by Francois PLANQUE - {@link http://fplanque.net/}
 *
 * {@internal License choice
 * - If you have received this file as part of a package, please find the license.txt file in
 *   the same folder or the closest folder above for complete license terms.
 * - If you have received this file individually (e-g: from http://evocms.cvs.sourceforge.net/)
 *   then you must choose one of the following licenses before using the file:
 *   - GNU General Public License 2 (GPL) - http://www.opensource.org/licenses/gpl-license.php
 *   - Mozilla Public License 1.1 (MPL) - http://www.opensource.org/licenses/mozilla1.1.php
 * }}
 *
 * {@internal Below is a list of authors who have contributed to design/coding of this file: }}
 * @author fplanque: Francois PLANQUE.
 *
 * @package widgets
 */
if( !defined('QP_MAIN_INIT') ) die( 'Please, do not access this page directly.' );

load_class( 'widgets/model/_widget.class.php' );


/**
 * @package widgets
 */
class menu_link_Widget extends ComponentWidget
{

	var $menu_link_widget_link_types = array();

	/**
	 * Constructor
	 */
	function menu_link_Widget( $db_row = NULL )
	{
		// Call parent constructor:
		parent::ComponentWidget( $db_row, 'widget', 'menu_link' );

		$this->widget_name = $this->T_('Menu link');
		$this->widget_title = '';
		$this->menu_link_widget_link_types = array(
			'home' => $this->T_('Blog home'),
			'arcdir' => $this->T_('Archive directory'),
			'catdir' => $this->T_('Category directory'),
			'latestcomments' => $this->T_('Latest comments'),
			'ownercontact' => $this->T_('Blog owner contact form'),
			'login' => $this->T_('Log in form')
		);
	}


	/**
	 * Get a very short desc. Used in the widget list.
	 */
	function get_short_desc()
	{
		$this->load_param_array();

		if( !empty($this->param_array['link_type']) )
		{
			// TRANS: %s is the link type, e. g. "Blog home" or "Log in form"
			return sprintf( $this->T_('%s link'), $this->menu_link_widget_link_types[$this->param_array['link_type']] );
		}
		else
		{
			return $this->get_name();
		}
	}



  /**
	 * Get short description
	 */
	function get_desc()
	{
		return $this->T_('Display a configurable menu entry/link');
	}


  /**
   * Get definitions for editable params
   *
	 * @see Plugin::GetDefaultSettings()
	 * @param local params like 'for_editing' => true
	 */
	function get_param_definitions( $params )
	{

		$r = array_merge( array(
				'link_type' => array(
					'label' => $this->T_('Link Type'),
					'note' => $this->T_('What do you want to link to?'),
					'type' => 'select',
					'options' => $this->menu_link_widget_link_types,
					'defaultvalue' => 'home',
				),
			), parent::get_param_definitions( $params )	);

		return $r;
	}


	/**
	 * Display the widget!
	 *
	 * @param array MUST contain at least the basic display params
	 */
	function display( $params )
	{
		global $Blog;

		$this->init_display( $params );

		switch(	$this->disp_params['link_type'] )
		{
			case 'arcdir':
				$url = $Blog->get('arcdirurl');
				$text = $this->T_('Archives');
				$title = $this->T_('visit this blog\'s archives');
				break;

			case 'catdir':
				$url = $Blog->get('catdirurl');
				$text = $this->T_('Categories');
				$title = $this->T_('visit this blog\'s categories');
				break;

			case 'latestcomments':
				$url = $Blog->get('lastcommentsurl');
				$text = $this->T_('Latest comments');
				$title = $this->T_('see this blog\'s latest comments');
				break;

			case 'ownercontact':
				$Blog->get_owner_User();
				// fp> TODO: move this test into $Blog->get_contact_url( true );
				if( ! $Blog->owner_User->allow_msgform )
				{ // user does not allow contact form
					return;
				}
				$url = $Blog->get_contact_url( true );
				$text = $this->T_('Contact');
				$title = $this->T_('send a message to the owner of this blog');
				break;

			case 'login':
				if( is_logged_in() ) return false;
				$url = get_login_url();
				$text = $this->T_('Log in');
				$title = $this->T_('login (if you have an account)');
				break;

			case 'home':
			default:
				$url = $Blog->get('url');
				$text = $this->T_('Home');
				$title = $this->T_('visit this blog\'s home page');
		}

		echo $this->disp_params['block_start'];
		$this->disp_title();
		echo $this->disp_params['list_start'];

		echo $this->disp_params['item_start'];
		echo '<a href="'.$url.'" title="'.$title.'">'.$text.'</a>';
		echo $this->disp_params['item_end'];

		echo $this->disp_params['list_end'];
		echo $this->disp_params['block_end'];

		return true;
	}
}
?>
