<?php
/**
 * This file implements the Quicktags Toolbar plugin for Quam Plures
 *
 * This is Ron's remix!
 * Includes code from the WordPress team -
 *  http://sourceforge.net/project/memberlist.php?group_id=51422
 *
 * Quam Plures - {@link http://quamplures.net/}
 * Released under GNU GPL License - {@link http://quamplures.net/license.html}
 * @copyright (c) 2009 by the Quam Plures developers - {@link http://quamplures.net/}
 * @copyright (c)2003-2009 by Francois PLANQUE - {@link http://fplanque.net/}
 *
 * @package plugins
 * @subpackage QuickTags
 */
if( !defined('QP_MAIN_INIT') ) die( 'Please, do not access this page directly.' );


/**
 * @package plugins
 * @subpackage QuickTags
 */
class quicktags_plugin extends Plugin
{
	var $code = 'quicktags';
	var $group = 'toolbars';
	var $number_of_installs = 1;
	var $priority = 30;
	var $version = '0.1';


	/**
	 * @see Plugin::PluginInit()
	 */
	function PluginInit( & $params )
	{
		$this->name = $this->T_('Quick Tags');
		$this->short_desc = $this->T_('Easy HTML tags inserting');
		$this->long_desc = $this->T_('This plugin will display 2 toolbars with buttons to quickly insert HTML tags around selected text in a post.');
	}


	/**
	 * @see Plugin::GetDefaultSettings()
	 */
	function GetDefaultSettings( & $params )
	{
		$default_settings = array(
			'enable_user' => array(
				'label' => $this->T_('enable user option'),
				'type' => 'checkbox',
				'defaultvalue' => '1',
				'note' => $this->T_('If checked, users can turn off this toolbar.'),
			),
			'toolbar_location' => array(
				'label' => $this->T_('toolbar location'),
				'type' => 'select',
				'options' => array(
					'above' => $this->T_('above post textarea'),
					'below' => $this->T_('below post textarea'),
					'right' => $this->T_('top of the sidebar'),
				),
				'defaultvalue' => 'above',
				'note' => $this->T_('Users will not be able to select where this toolbar goes.'),
			),
		);
		return $default_settings;
	}


	/**
	 * @see Plugin::GetDefaultUserSettings()
	 */
	function GetDefaultUserSettings( & $params )
	{
		if( ! $this->Settings->get( 'enable_user' ) )
		{
			return false;
		}
		$user_settings = array(
			'use_toolbar' => array(
				'label' => sprintf( $this->T_('"%s" toolbar'), $this->name ),
				'defaultvalue' => '1',
				'type' => 'checkbox',
				'note' => sprintf( $this->T_('Check this to enable the "%s" toolbar.'), $this->name ),
			),
		);
		return $user_settings;
	}


	/**
	 * @see Plugin::AdminDisplayToolbarAbove()
	 */
	function AdminDisplayToolbarAbove( & $params )
	{
		$show_toolbar = ( $this->Settings->get('enable_user') ? $this->UserSettings->get('use_toolbar') : true );
		if( ($this->Settings->get('toolbar_location') == 'above') && $show_toolbar )
		{
			return $this->make_the_toolbar( $params );
		}
		return false;
	}


	/**
	 * @see Plugin::AdminDisplayToolbarBelow()
	 */
	function AdminDisplayToolbarBelow( & $params )
	{
		$show_toolbar = ( $this->Settings->get('enable_user') ? $this->UserSettings->get('use_toolbar') : true );
		if( ($this->Settings->get('toolbar_location') == 'below') && $show_toolbar )
		{
			return $this->make_the_toolbar( $params );
		}
		return false;
	}


	/**
	 * @see Plugin::AdminDisplayToolbarSidebar()
	 */
	function AdminDisplayToolbarSidebar( & $params )
	{
		$show_toolbar = ( $this->Settings->get('enable_user') ? $this->UserSettings->get('use_toolbar') : true );
		if( ($this->Settings->get('toolbar_location') == 'right') && $show_toolbar )
		{
			return $this->make_the_toolbar( $params );
		}
		return false;
	}


	/**
	 * @see Plugin::TemplateBeginHtmlHead()
	 */
	function TemplateBeginHtmlHead()
	{
		echo "\n".'<link rel="stylesheet" type="text/css" href="'.$this->get_plugin_url().'quicktags.css" media="screen" />'."\n";
	}


	/**
	 * @see Plugin::AdminEndHtmlHead()
	 */
	function AdminEndHtmlHead( & $params )
	{
		$this->TemplateBeginHtmlHead();
	}


	/**
	 * actually finally create the toolbar :)
	 */
	function make_the_toolbar( $params )
	{
		global $Hit;

		if( $Hit->is_lynx() )
		{ // let's deactivate quicktags on Lynx, because they don't work there.
			return false;
		}
		?>

		<script type="text/javascript">
		//<![CDATA[
		var QP_Links = new Array();
		var QP_Links2 = new Array();
		var QP_Buttons = new Array();
		var QP_Buttons2 = new Array();
		var QP_OpenTags = new Array();
		var QP_OpenTags2 = new Array();



		function QP_Button(id, display, style, tagStart, tagEnd, access, tit, open)
		{
			this.id = id;							// used to name the toolbar button
			this.display = display;		// label on button
			this.style = style;				// style on button
			this.tagStart = tagStart; // open tag
			this.tagEnd = tagEnd;			// close tag
			this.access = access;			// access key
			this.tit = tit;						// title
			this.open = open;					// set to -1 if tag does not need to be closed
		}


		function QP_Button2(id, display, tagClass, tagStart, tagEnd, tit, open)
		{
			this.id = id;
			this.display = display;
			this.tagClass = tagClass;
			this.tagStart = tagStart;
			this.tagEnd = tagEnd;
			this.tit = tit;
			this.open = open;
		}


		QP_Buttons[QP_Buttons.length] = new QP_Button(
			'QP_ins', 'ins', '', '<ins>', '<\/ins>', 'b', '<?php echo $this->T_('INSerted') ?>'
		);
		QP_Buttons[QP_Buttons.length] = new QP_Button(
			'QP_del', 'del', 'text-decoration:line-through;', '<del>', '<\/del>', 'i', '<?php echo $this->T_('DELeted') ?>'
		);
		QP_Buttons[QP_Buttons.length] = new QP_Button(
			'QP_strong', 'str', 'font-weight:bold;', '<strong>', '<\/strong>', 's', '<?php echo $this->T_('STRong [Alt-S]') ?>'
		);
		QP_Buttons[QP_Buttons.length] = new QP_Button(
			'QP_em', 'em', 'font-style:italic;', '<em>', '<\/em>', 'e', '<?php echo $this->T_('EMphasis [Alt-E]') ?>'
		);
		QP_Buttons[QP_Buttons.length] = new QP_Button(
			'QP_code', 'code', '', '<code>', '<\/code>', 'c', '<?php echo $this->T_('CODE [Alt-C]') ?>'
		);
		QP_Buttons[QP_Buttons.length] = new QP_Button(
			'QP_par', 'p', 'margin-left:8px;', '<p>', '<\/p>', 'p', '<?php echo $this->T_('Paragraph [Alt-P]') ?>'
		);
		QP_Buttons[QP_Buttons.length] = new QP_Button(
			'QP_block', 'block', '', '<blockquote>', '<\/blockquote>', 'b', '<?php echo $this->T_('BLOCKQUOTE [Alt-B]') ?>'
		);
		QP_Buttons[QP_Buttons.length] = new QP_Button(
			'QP_pre', 'pre', '', '<pre>', '<\/pre>', 'r', '<?php echo $this->T_('PREformatted text [Alt-R]') ?>'
		);
		QP_Buttons[QP_Buttons.length] = new QP_Button(
			'QP_ul', 'ul', '', '<ul>\n', '<\/ul>\n\n', 'u', '<?php echo $this->T_('Unordered List [Alt-U]') ?>'
		);
		QP_Buttons[QP_Buttons.length] = new QP_Button(
			'QP_ol', 'ol', '', '<ol>\n', '<\/ol>\n\n', 'o', '<?php echo $this->T_('Ordered List [Alt-O]') ?>'
		);
		QP_Buttons[QP_Buttons.length] = new QP_Button(
			'QP_li', 'li', '', '<li>', '<\/li>\n', 'l', '<?php echo $this->T_('List Item [Alt-L]') ?>'
		);
		QP_Buttons[QP_Buttons.length] = new QP_Button(
			'QP_img', 'img', 'margin-left:8px;', '', '', 'g', '<?php echo $this->T_('IMaGe [Alt-G]') ?>'
			, -1
		); // special case
		QP_Buttons[QP_Buttons.length] = new QP_Button(
			'QP_link', 'link', 'text-decoration:underline;', '', '<\/a>', 'a', '<?php echo $this->T_('A href [Alt-A]') ?>'
		);
		QP_Buttons[QP_Buttons.length] = new QP_Button(
			'QP_more', '!M', 'margin-left:8px;', '<!-'+'-more-'+'->', '', 'm', '<?php echo $this->T_('More [Alt-M]') ?>'
			, -1
		); // special case
		QP_Buttons[QP_Buttons.length] = new QP_Button(
			'QP_noteaser', '!NT', '', '<!-'+'-noteaser-'+'->', '', 't', '<?php echo $this->T_('no teaser [Alt-T]') ?>'
			, -1
		); // special case
		QP_Buttons[QP_Buttons.length] = new QP_Button(
			'QP_next', '!NP', '', '<!-'+'-nextpage-'+'->', '', 'q', '<?php echo $this->T_('next page [Alt-Q]') ?>'
			, -1
		); // special case


		QP_Buttons2[QP_Buttons2.length] = new QP_Button2(
			'QP_red', 'R', 'spans red', '<span class="red">', '<\/span>', '<?php echo $this->T_('red') ?>'
		);
		QP_Buttons2[QP_Buttons2.length] = new QP_Button2(
			'QP_ora', 'O', 'spans orange', '<span class="orange">', '<\/span>', '<?php echo $this->T_('orange') ?>'
		);
		QP_Buttons2[QP_Buttons2.length] = new QP_Button2(
			'QP_yel', 'Y', 'spans yellow', '<span class="yellow">', '<\/span>', '<?php echo $this->T_('yellow') ?>'
		);
		QP_Buttons2[QP_Buttons2.length] = new QP_Button2(
			'QP_gre', 'G', 'spans green', '<span class="green">', '<\/span>', '<?php echo $this->T_('green') ?>'
		);
		QP_Buttons2[QP_Buttons2.length] = new QP_Button2(
			'QP_blu', 'B', 'spans blue', '<span class="blue">', '<\/span>', '<?php echo $this->T_('blue') ?>'
		);
		QP_Buttons2[QP_Buttons2.length] = new QP_Button2(
			'QP_ind', 'I', 'spans indigo', '<span class="indigo">', '<\/span>', '<?php echo $this->T_('indigo') ?>'
		);
		QP_Buttons2[QP_Buttons2.length] = new QP_Button2(
			'QP_vio', 'V', 'spans violet', '<span class="violet">', '<\/span>', '<?php echo $this->T_('violet') ?>'
		);
		QP_Buttons2[QP_Buttons2.length] = new QP_Button2(
			'QP_blk', 'BLK', 'spans leftgap black', '<span class="black">', '<\/span>', '<?php echo $this->T_('black') ?>'
		);
		QP_Buttons2[QP_Buttons2.length] = new QP_Button2(
			'QP_wht', 'WHT', 'spans white', '<span class="white">', '<\/span>', '<?php echo $this->T_('white') ?>'
		);
		QP_Buttons2[QP_Buttons2.length] = new QP_Button2(
			'QP_large', 't +', 'leftgap spans', '<span class="larger">', '<\/span>', '<?php echo $this->T_('larger') ?>'
		);
		QP_Buttons2[QP_Buttons2.length] = new QP_Button2(
			'QP_small', 't -', 'spans', '<span class="smaller">', '<\/span>', '<?php echo $this->T_('smaller') ?>'
		);
		QP_Buttons2[QP_Buttons2.length] = new QP_Button2(
			'QP_under', '_', 'spans', '<span class="underline">', '<\/span>', '<?php echo $this->T_('underline') ?>'
		);
		QP_Buttons2[QP_Buttons2.length] = new QP_Button2(
			'QP_h1', 'h1', 'leftgap', '<h1>', '<\/h1>', '<?php echo $this->T_('H1') ?>'
		);
		QP_Buttons2[QP_Buttons2.length] = new QP_Button2(
			'QP_h2', 'h2', '', '<h2>', '<\/h2>', '<?php echo $this->T_('H2') ?>'
		);
		QP_Buttons2[QP_Buttons2.length] = new QP_Button2(
			'QP_h3', 'h3', '', '<h3>', '<\/h3>', '<?php echo $this->T_('H3') ?>'
		);
		QP_Buttons2[QP_Buttons2.length] = new QP_Button2(
			'QP_h4', 'h4', '', '<h4>', '<\/h4>', '<?php echo $this->T_('H4') ?>'
		);
		QP_Buttons2[QP_Buttons2.length] = new QP_Button2(
			'QP_h5', 'h5', '', '<h5>', '<\/h5>', '<?php echo $this->T_('H5') ?>'
		);
		QP_Buttons2[QP_Buttons2.length] = new QP_Button2(
			'QP_h6', 'h6', '', '<h6>', '<\/h6>', '<?php echo $this->T_('H6') ?>'
		);


		// make the first toolbar
		function QP_Toolbar()
		{
			document.write('<div class="qp_1">');
			for (var i = 0; i < QP_Buttons.length; i++)
			{
				QP_ShowButton(QP_Buttons[i], i);
			}
			document.write('<input type="button" id="QP_close" class="quicktags" onclick="QP_CloseAllTags();" title="<?php echo $this->T_('Close all tags') ?>" value="X" style="margin-left:8px;" />');
			document.write('<\/div>');
		}
		// make the second toolbar
		function QP_Toolbar2()
		{
			document.write('<div class="qp_2">');
			for (var i = 0; i < QP_Buttons2.length; i++)
			{
				QP_ShowButton2(QP_Buttons2[i], i);
			}
			document.write('<input type="button" id="QP_close2" class="quicktags" onclick="QP_CloseAllTags2();" title="<?php echo $this->T_('Close all tags') ?>" value="X" style="margin-left:8px;" />');
			document.write('<\/div>');
		}


		// create each button for the first toolbar
		function QP_ShowButton(button, i)
		{
			if( button.id == 'QP_img' )
			{
				document.write('<input type="button" id="' + button.id + '" accesskey="' + button.access + '" title="' + button.tit
					+ '" style="' + button.style + '" class="quicktags" onclick="QP_InsertImage(app_Canvas);" value="' + button.display + '" />');
			}
			else if( button.id == 'QP_link' )
			{
				document.write('<input type="button" id="' + button.id + '" accesskey="' + button.access + '" title="' + button.tit
					+ '" style="' + button.style + '" class="quicktags" onclick="QP_InsertLink(app_Canvas, ' + i + ');" value="' + button.display + '" />');
			}
			else
			{ // Normal buttons:
				document.write('<input type="button" id="' + button.id + '" accesskey="' + button.access + '" title="' + button.tit
					+ '" style="' + button.style + '" class="quicktags" onclick="QP_InsertTag(app_Canvas, ' + i + ');" value="' + button.display + '"  />');
			}
		}
		// create each button for the second toolbar
		function QP_ShowButton2(button, i)
		{
			document.write('<input type="button" id="' + button.id + '" title="' + button.tit + '" class="' + button.tagClass + '" onclick="QP_InsertTag2(app_Canvas, ' + i + ');" value="' + button.display + '"  />');
		}


		// close all open tags for the first toolbar
		function QP_CloseAllTags()
		{
			var count = QP_OpenTags.length;
			for (o = 0; o < count; o++)
			{
				QP_InsertTag(app_Canvas, QP_OpenTags[QP_OpenTags.length - 1]);
			}
		}
		// close all open tags for the second toolbar
		function QP_CloseAllTags2()
		{
			var count = QP_OpenTags2.length;
			for (o = 0; o < count; o++)
			{
				QP_InsertTag2(app_Canvas, QP_OpenTags2[QP_OpenTags2.length - 1]);
			}
		}


		// first toolbar only - insert image
		function QP_InsertImage(myField)
		{
			var myValue = prompt( '<?php echo $this->T_('URL') ?>:', 'http://' );
			if (myValue) {
				myValue = '<img src="'
					+ myValue
					+ '" alt="' + prompt('<?php echo $this->T_('ALTernate text') ?>:', '')
					+ '" title="' + prompt('<?php echo $this->T_('Title') ?>:', '')
					+ '" />';
				textarea_wrap_selection( myField, myValue, '', 1 );
			}
		}


		// first toolbar only - insert link
		function QP_InsertLink(myField, i, defaultValue)
		{
			if (!defaultValue)
			{
				defaultValue = 'http://';
			}

			if (!QP_CheckOpenTags(i)) {
				var URL = prompt( '<?php echo $this->T_('URL') ?>:', defaultValue);
				if (URL)
				{
					QP_Buttons[i].tagStart = '<a href="' + URL + '">';
					QP_InsertTag(myField, i);
				}
			}
			else
			{
				QP_InsertTag( myField, i );
			}
		}


		// insertion code for the first toolbar
		function QP_InsertTag( myField, i )
		{
			// we need to know if something is selected. First ask plugins, then try IE and Mozilla.
			var sel_text = b2evo_Callbacks.trigger_callback("get_selected_text_for_"+myField.id);
			var focus_when_finished = false; // used for IE

			if( sel_text == null )
			{ // detect selection:
				//IE support
				if(document.selection)
				{
					myField.focus();
					var sel = document.selection.createRange();
					sel_text = sel.text;
					focus_when_finished = true;
				}
				//MOZILLA/NETSCAPE support
				else if(myField.selectionStart || myField.selectionStart == '0')
				{
					var startPos = myField.selectionStart;
					var endPos = myField.selectionEnd;
					sel_text = (startPos != endPos);
				}
			}
			if( sel_text )
			{ // some text selected
				textarea_wrap_selection( myField, QP_Buttons[i].tagStart, QP_Buttons[i].tagEnd, 0 );
			}
			else
			{
				if( !QP_CheckOpenTags(i) || QP_Buttons[i].tagEnd == '')
				{
					textarea_wrap_selection( myField, QP_Buttons[i].tagStart, '', 0 );
					QP_AddTag(i);
				}
				else
				{
					textarea_wrap_selection( myField, '', QP_Buttons[i].tagEnd, 0 );
					QP_RemoveTag(i);
				}
			}
			if(focus_when_finished)
			{
				myField.focus();
			}
		}
		// insertion code for the second toolbar
		function QP_InsertTag2( myField, i )
		{
			// we need to know if something is selected. First ask plugins, then try IE and Mozilla.
			var sel_text = b2evo_Callbacks.trigger_callback("get_selected_text_for_"+myField.id);
			var focus_when_finished = false; // used for IE

			if( sel_text == null )
			{ // detect selection:
				//IE support
				if(document.selection)
				{
					myField.focus();
					var sel = document.selection.createRange();
					sel_text = sel.text;
					focus_when_finished = true;
				}
				//MOZILLA/NETSCAPE support
				else if(myField.selectionStart || myField.selectionStart == '0')
				{
					var startPos = myField.selectionStart;
					var endPos = myField.selectionEnd;
					sel_text = (startPos != endPos);
				}
			}
			if( sel_text )
			{ // some text selected
				textarea_wrap_selection( myField, QP_Buttons2[i].tagStart, QP_Buttons2[i].tagEnd, 0 );
			}
			else
			{
				if( !QP_CheckOpenTags2(i) || QP_Buttons2[i].tagEnd == '')
				{
					textarea_wrap_selection( myField, QP_Buttons2[i].tagStart, '', 0 );
					QP_AddTag2(i);
				}
				else
				{
					textarea_wrap_selection( myField, '', QP_Buttons2[i].tagEnd, 0 );
					QP_RemoveTag2(i);
				}
			}
			if(focus_when_finished)
			{
				myField.focus();
			}
		}


		// check/count open tags for the first toolbar
		function QP_CheckOpenTags(button)
		{
			var tag = 0;
			for (i = 0; i < QP_OpenTags.length; i++)
			{
				if (QP_OpenTags[i] == button)
				{
					tag++;
				}
			}
			if (tag > 0)
			{
				return true; // tag found
			}
			else
			{
				return false; // tag not found
			}
		}
		// check/count open tags for the second toolbar
		function QP_CheckOpenTags2(button)
		{
			var tag = 0;
			for (i = 0; i < QP_OpenTags2.length; i++)
			{
				if (QP_OpenTags2[i] == button)
				{
					tag++;
				}
			}
			if (tag > 0)
			{
				return true; // tag found
			}
			else
			{
				return false; // tag not found
			}
		}


		// Memorize a new open tag for the first toolbar
		function QP_AddTag(button)
		{
			if( QP_Buttons[button].tagEnd != '' )
			{
				QP_OpenTags[QP_OpenTags.length] = button;
				document.getElementById(QP_Buttons[button].id).value = '/' + document.getElementById(QP_Buttons[button].id).value;
			}
		}
		// Memorize a new open tag for the second toolbar
		function QP_AddTag2(button)
		{
			if( QP_Buttons2[button].tagEnd != '' )
			{
				QP_OpenTags2[QP_OpenTags2.length] = button;
				document.getElementById(QP_Buttons2[button].id).value = '/' + document.getElementById(QP_Buttons2[button].id).value;
			}
		}


		// Forget about an open tag for the first toolbar
		function QP_RemoveTag(button)
		{
			for (i = 0; i < QP_OpenTags.length; i++)
			{
				if (QP_OpenTags[i] == button)
				{
					QP_OpenTags.splice(i, 1);
					document.getElementById(QP_Buttons[button].id).value = document.getElementById(QP_Buttons[button].id).value.replace('/', '');
				}
			}
		}
		// Forget about an open tag for the second toolbar
		function QP_RemoveTag2(button)
		{
			for (i = 0; i < QP_OpenTags2.length; i++)
			{
				if (QP_OpenTags2[i] == button)
				{
					QP_OpenTags2.splice(i, 1);
					document.getElementById(QP_Buttons2[button].id).value = document.getElementById(QP_Buttons2[button].id).value.replace('/', '');
				}
			}
		}
		//]]>
		</script>

		<div class="edit_toolbar"><script type="text/javascript">QP_Toolbar();</script></div>
		<div class="edit_toolbar"><script type="text/javascript">QP_Toolbar2();</script></div>

		<?php
		return true;
	}

}
?>
