<?php
/**
 * This file implements the TEST plugin.
 *
 * This is a "docblock".  You don't need to have them in your plugin unless you 
 * want your plugin considered for inclusion in the core package one day. If so 
 * then you need one for the class with @package and @subpackage, and one for each 
 * function.
 *
 * This file is part of Quam Plures - {@link http://quamplures.net/}, See also 
 * {@link https://launchpad.net/quam-plures}. For the most recent and complete 
 * Plugin API documentation see {@link Plugin} in ../evocore/_plugin.class.php.
 *
 * @copyright (c) 2009 by the Quam Plures developers - {@link http://quamplures.net/}
 * @copyright (c)2003-2009 by Francois PLANQUE - {@link http://fplanque.net/}
 * Parts of this file are copyright (c)2004-2006 by Daniel HAHLER - {@link http://thequod.de/contact}.
 *
 * @package plugins
 * @subpackage Test
 */

/*
 * ORIGINAL AUTHORSHIP / LICENSING INFO...
 *
 * {@internal License choice
 * - If you have received this file as part of a package, please find the license.txt file in
 *   the same folder or the closest folder above for complete license terms.
 * - If you have received this file individually (e-g: from http://evocms.cvs.sourceforge.net/)
 *   then you must choose one of the following licenses before using the file:
 *   - GNU General Public License 2 (GPL) - http://www.opensource.org/licenses/gpl-license.php
 *   - Mozilla Public License 1.1 (MPL) - http://www.opensource.org/licenses/mozilla1.1.php
 * }}
 *
 * {@internal Open Source relicensing agreement:
 * Daniel HAHLER grants Francois PLANQUE the right to license
 * Daniel HAHLER's contributions to this file and the b2evolution project
 * under any OSI approved OSS license (http://www.opensource.org/licenses/).
 * }}
 *
 * {@internal Below is a list of authors who have contributed to design/coding of this file: }}
 * @author fplanque: Francois PLANQUE - {@link http://fplanque.net/}
 * @author blueyed: Daniel HAHLER
 *
 */
if( !defined('QP_MAIN_INIT') ) die( 'Please, do not access this page directly.' );


/**
 * @package plugins
 * @subpackage Test
 */
class test_plugin extends Plugin
{
	var $apply_rendering = 'opt-out';
	var $author = 'Your Name';
	var $author_url = 'http://yourdomain.tld/';
	var $code = 'test';
	var $group = 'other';
	var $sub_group = 'plugin demo'; // used if $group is 'other'
	var $number_of_installs = 1;
	var $priority = 50;
	var $version = '0.1';


	/**
	 * @see Plugin::PluginInit()
	 */
	function PluginInit( & $params )
	{
		$this->name = $this->T_('Test / Demo');
		$this->short_desc = $this->T_('Test plugin, responds to most plugin events.');
		$this->long_desc = $this->T_('This plugin responds to virtually all possible plugin events and provides samples of how to do stuff with your plugins.');

		// Trigger plugin settings instantiation (for testing).
		if( $params['is_installed'] )
		{
			$this->Settings->get('foo');
		}
	}


	/**
	 * @see Plugin::GetDbLayout()
	 */
	function GetDbLayout()
	{
		return array(
			"CREATE TABLE IF NOT EXISTS ".$this->get_sql_table( 'testplugin' )." (
				autoinc_int INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
				an_int INT(10) UNSIGNED NOT NULL,
				a_varchar VARCHAR(255) NOT NULL,
				a_float Float(10,2) NOT NULL,
				a_decimal DECIMAL(10,4) NOT NULL,
				a_datetime DATETIME NOT NULL,
				PRIMARY KEY (autoinc_int),
				KEY (an_int)
			)",
		);
	}


	/**
	 * @see Plugin::GetDefaultSettings()
	 */
	function GetDefaultSettings( & $params )
	{
		global $app_name;

		$default_settings = array(
			'click_me' => array(
				'label' => $this->T_('Click me!'),
				'defaultvalue' => '1',
				'type' => 'checkbox',
			),
			'input_me' => array(
				'label' => $this->T_('How are you?'),
				'defaultvalue' => '',
				'note' => sprintf( /* TRANS: %s: Application name */ $this->T_('Welcome to %s'), $app_name ),
			),
			'number' => array(
				'label' => $this->T_('Number'),
				'defaultvalue' => '8',
				'note' => '1-9',
				'valid_range' => array( 'min'=>1, 'max'=>9 ),
			),
			'my_select' => array(
				'label' => $this->T_('Selector'),
				'id' => $this->classname.'_my_select',
				'onchange' => 'document.getElementById("'.$this->classname.'_a_disabled_one").disabled = ( this.value == "sun" );',
				'defaultvalue' => 'one',
				'type' => 'select',
				'options' => array( 'sun' => 'Sunday', 'mon' => 'Monday' ),
				'note' => '',
			),
			'a_disabled_one' => array(
				'label' => $this->T_('This one is disabled'),
				'id' => $this->classname.'_a_disabled_one',
				'type' => 'checkbox',
				'defaultvalue' => '1',
				'disabled' => true, // this can be useful if you detect that something cannot be changed. You probably want to add a 'note' then, too.
				'note' => $this->T_('Change the above select input to "Monday" to enable it.'),
			),
			'select_multiple' => array(
				'label' => $this->T_('Multiple select'),
				'type' => 'select',
				'multiple' => true,
				'allow_none' => true,
				'options' => array( 'sci' => $this->T_('Scissors'), 'pap' => $this->T_('Paper'), 'sto' => $this->T_('Stone') ),
				'defaultvalue' => array( 'sci', 'sto' ),
				'note' => $this->T_('This is a free style Multiple Select. You can choose zero or one or more items')
			),
			/*
			 * note: The $this->T_('string') function tanslates the string.
			 * However since it inherits from the class Plugin you will need
			 * to provide the translation on a per plugin basis. In other
			 * words: this will not be translated through Quam Plures.
			 */
			'blog' => array(
				'label' => $this->T_('A blog'),
				'type' => 'select_blog',  // TODO: does not scale with 500 blogs
				'allow_none' => true,
			),
			'blogs' => array(
				'label' => $this->T_('A set of blogs'),
				'type' => 'select_blog',	// TODO: BROKEN + does not scale with 500 blogs
				'multiple' => true,
				'allow_none' => true,
			),
			'single_user' => array(
				'label' => $this->T_('A single user'),
				'type' => 'select_user',
				'allow_none' => true,
				'default_value' => 0,
				'note' => $this->T_('Allows chosing none or one user'),
			),
			'sets' => array(
				'type' => 'select_user',
				'label' => $this->T_('Multiple users'),
				'min_count' => 0,
				'max_count' => 3,
				'multiple' => 'true',
				'allow_none' => true,
				'note' => $this->T_('Allows none or one or more than one user (up to three in this example)'),
				'entries' => array(
					'user' => array(
						'label' => $this->T_('A user'),
						'type' => 'select_user',		// TODO: does not scale with 500 users
						'allow_none' => true,
					),
				),
			),
			'maxlen' => array(
				'label' => $this->T_('Max'),
				'type' => 'textarea',
				'maxlength' => 10,
				'note' => $this->T_('Maximum length is 10 here.'),
			),
		);

		if( $params['for_editing'] )
		{ // we're asked for the settings for editing:
			if( $this->Settings->get('my_select') == 'mon' )
			{
				$r['a_disabled_one']['disabled'] = false;
			}
		}
		return $default_settings;
	}


	/**
	 * @see Plugin::GetDefaultUserSettings()
	 */
	function GetDefaultUserSettings( & $params )
	{
		$user_settings = array(
			'echo_random' => array(
				'label' => $this->T_('Echo a random number in AdminBeginPayload event'),
				'type' => 'checkbox',
				'defaultvalue' => '0',
			),
			'deactivate' => array(
				'label' => $this->T_('Deactivate'),
				'type' => 'checkbox',
				'defaultvalue' => '0',
			),
		);
		return $user_settings;
	}


	/**
	 * @see Plugin::GetExtraEvents()
	 */
	function GetExtraEvents()
	{
		return array(
				// Gets "min" and "max" as params and should return a random number in between:
				'test_plugin_get_random' => $this->T_('TEST plugin event that returns a random number.'),
			);
	}


	/**
	 * @see Plugin::GetCronJobs()
	 */
	function GetCronJobs( & $params )
	{
		return array(
				array(
					'name' => $this->T_('TEST plugin - cron job'),
					'ctrl' => 'test_job',
					'params' => array( 'param' => 1 ),
				),
			);
	}


	/**
	 * @see Plugin::ExecCronJob()
	 */
	function ExecCronJob( & $params )
	{
		if( $params['ctrl'] == 'test_job' )
		{
			return array( 'code' => 1, 'message' => $this->T_('Test successful.') );
		}
	}


	/**
	 * @see Plugin::AppendLoginRegisteredUser()
	 *
	 * @todo EdB: this hook does not exist!!! Should be AfterLoginRegisteredUser?
	 */
	function AppendLoginRegisteredUser()
	{
		if( $this->UserSettings->get('deactivate') )
		{
			$this->forget_events();
		}
	}


	/**
	 * @see Plugin::GetDependencies()
	 */
	function GetDependencies()
	{
		return array(
				'recommends' => array(
					'events_by_one' => array( array('Foo', 'Bar'), array('FooBar', 'BarFoo') ), // a plugin that provides "Foo" and "Bar", and one (may be the same) that provides "FooBar" and "BarFoo"
					'events' => array( 'some_event', 'some_other_event' ),
					'plugins' => array( array( 'some_plugin', '1' ) ), // at least version 1 of some_plugin
				),

				'requires' => array(
					// Same syntax as with the 'recommends' class above, but would prevent the plugin from being installed.
				),
			);
	}


	/**
	 * @see Plugin::PluginUserSettingsUpdateAction()
	 */
	function PluginUserSettingsUpdateAction( & $params )
	{
		if( $this->UserSettings->get('echo_random') )
		{
			$this->msg( $this->T_('TEST plugin: Random numbers have been disabled.') );
		}
		else
		{
			$this->msg( $this->T_('TEST plugin: Random numbers have been enabled.') );
		}

		return true;
	}


	/**
	 * @see Plugin::AdminEndHtmlHead()
	 */
	function AdminEndHtmlHead( & $params )
	{
		echo '<!-- This is the TEST plugin responding to the "AdminEndHtmlHead" event. -->';

		return true;
	}


	/**
	 * @see Plugin::AdminAfterPageFooter()
	 */
	function AdminAfterPageFooter( & $params )
	{
		echo '<p class="footer">'.sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'AdminAfterPageFooter' ).'</p>';

		return true;
	}


	/**
	 * @see Plugin::AdminDisplayToolbarAbove()
	 */
	function AdminDisplayToolbarAbove( & $params )
	{
		echo sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'AdminDisplayToolbarAbove' );

		return true;
	}


	/**
	 * @see Plugin::AdminDisplayToolbarBelow()
	 */
	function AdminDisplayToolbarBelow( & $params )
	{
		echo sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'AdminDisplayToolbarBelow' );

		return true;
	}


	/**
	 * @see Plugin::AdminDisplayToolbarSidebar()
	 */
	function AdminDisplayToolbarSidebar( & $params )
	{
		echo sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'AdminDisplayToolbarSidebar' );

		return true;
	}


	/**
	 * @see Plugin::AdminDisplayEditorButton()
	 */
	function AdminDisplayEditorButton( & $params )
	{
		?>
		<input type="button" value="TEST" onclick="alert('<?php echo sprintf( $this->T_('This is the TEST plugin responding to the %s event.'), 'AdminDisplayEditorButton' ); ?>');" />
		<?php
		return true;
	}


	/**
	 * @see Plugin::AdminDisplayFieldsetAbove()
	 */
	function AdminDisplayFieldsetAbove( & $params )
	{
		$params['Form']->begin_fieldset( $this->T_('TEST plugin') );
		$params['Form']->info_field( $this->T_('TEST plugin'), sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'AdminDisplayFieldsetAbove' ) );
		$params['Form']->end_fieldset( 'Foo' );
	}


	/**
	 * @see Plugin::AdminDisplayFieldsetBelow()
	 */
	function AdminDisplayFieldsetBelow( & $params )
	{
		$params['Form']->begin_fieldset( $this->T_('TEST plugin') );
		$params['Form']->info_field( $this->T_('TEST plugin'), sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'AdminDisplayFieldsetBelow' ) );
		$params['Form']->end_fieldset( 'Foo' );
	}


	/**
	 * @see Plugin::AdminDisplayFieldsetSidebar()
	 */
	function AdminDisplayFieldsetSidebar( & $params )
	{
		$params['Form']->begin_fieldset( $this->T_('TEST plugin') );
		$params['Form']->info_field( $this->T_('TEST plugin'), sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'AdminDisplayFieldsetSidebar' ) );
		$params['Form']->end_fieldset( 'Foo' );
	}


	/**
	 * @see Plugin::TemplateBeginHtmlHead()
	 */
	function TemplateBeginHtmlHead()
	{
		require_js( '#jquery#');
	}


	/**
	 * @see Plugin::AdminBeforeItemEditCreate()
	 */
	function AdminBeforeItemEditCreate( & $params )
	{
		$this->msg( sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'AdminBeforeItemEditCreate' ) );
	}


	/**
	 * @see Plugin::AdminBeforeItemEditUpdate()
	 */
	function AdminBeforeItemEditUpdate( & $params )
	{
		$this->msg( sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'AdminBeforeItemEditUpdate' ) );
	}


	/**
	 * @see Plugin::AdminDisplayCommentFormFieldset()
	 */
	function AdminDisplayCommentFormFieldset( & $params )
	{
		$params['Form']->begin_fieldset( $this->T_('TEST plugin') );
		$params['Form']->info_field( $this->T_('TEST plugin'), sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'AdminDisplayCommentFormFieldset' ) );
		$params['Form']->end_fieldset( 'Foo' );
	}


	/**
	 * @see Plugin::AdminAfterNavbarInit()
	 */
	function AdminAfterNavbarInit()
	{
		// The following is a tiny bit hackish and should probably be abstracted a bit, but just a little bit
		// The idea is too let plugins hook pretty much anywhere into the menu structure, including Left AND Right menus.

		global $topleft_Menu;
		$topleft_Menu->add_menu_entries( 'tools', array(
				'urls_sep' => array(
						'separator' => true,
					),
				'urls' => array(
						'text' => $this->T_('TEST plugin').'&hellip;',
						'href' => $this->get_tools_tab_url(),
					),
			) );

	}


	/**
	 * @see Plugin::AdminAfterMenuInit()
	 */
	function AdminAfterMenuInit()
	{
		$this->register_menu_entry( $this->T_('TEST plugin tab') );
	}


	/**
	 * @see Plugin::AdminToolAction()
	 */
	function AdminToolAction( $params )
	{
		global $Messages;

		$Messages->add( sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'AdminToolAction' ) );
	}


	/**
	 * @see Plugin::AdminToolPayload()
	 */
	function AdminToolPayload( $params )
	{
		echo sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'AdminToolPayload' );
	}


	/**
	 * Event handler: Method that gets invoked when our tab (?tab=plug_ID_X) is selected.
	 *
	 * You should catch params (GET/POST) here and do actions (no output!).
	 * Use {@link $Messages} to add messages for the user.
	 *
	 * @see Plugin::AdminTabAction()
	 */
	function AdminTabAction()
	{
		global $Plugins;

		$this->text_from_AdminTabAction = '<p>'.sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'AdminTabAction' ).'</p>'
			.'<p>'.$this->T_('Here is a random number').': '
			.$Plugins->get_trigger_event_first_return('test_plugin_get_random', array( 'min'=>-1000, 'max'=>1000 )).'</p>';

		if( $this->param_text = param( $this->get_class_id('text') ) )
		{
			$this->text_from_AdminTabAction .= '<p>'.$this->T_('You have said').': '.$this->param_text.'</p>';
		}
	}


	/**
	 * Event handler: Gets invoked when our tab is selected and should get displayed.
	 *
	 * @see Plugin::AdminTabPayload()
	 */
	function AdminTabPayload()
	{
		echo sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'AdminTabPayload' );

		echo $this->text_from_AdminTabAction;

		// TODO: this is tedious.. should either be a global function (get_admin_Form()) or a plugin helper..
		$Form = new Form();
		$Form->begin_form();
		$Form->hidden_ctrl(); // needed to pass the "ctrl=tools" param
		$Form->hiddens_by_key( get_memorized() ); // needed to pass all other memorized params, especially "tab"

		$Form->text_input( $this->get_class_id().'_text', $this->param_text, '20', 'Text' );

		$Form->button_input(); // default "submit" button

		$Form->end_form();
	}


	/**
	 * @see Plugin::AdminBeginPayload()
	 */
	function AdminBeginPayload()
	{
		global $Plugins;

		echo '<div class="panelblock center">'.sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'AdminBeginPayload' ).'</div>';

	}


	/**
	 * Event handler: Called when rendering item/post contents as HTML.
	 *
	 * Note: return value is ignored. You have to change $params['content'].
	 *
	 * @see Plugin::RenderItemAsHtml()
	 */
	function RenderItemAsHtml( & $params )
	{
		$params['data'] = sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'RenderItemAsHtml' ).'<br />'.$params['data'];
	}


	/**
	 * Event handler: Called when rendering item/post contents as XML.
	 *
	 * Note: return value is ignored. You have to change $params['content'].
	 *
	 * @see Plugin::RenderItemAsXml()
	 */
	function RenderItemAsXml( & $params )
	{
		// Do the same as with HTML:
		$this->RenderItemAsHtml( $params );
	}


	/**
	 * Event handler: Called when rendering item/post contents as text.
	 *
	 * Note: return value is ignored. You have to change $params['content'].
	 *
	 * @see Plugin::RenderItemAsText()
	 */
	function RenderItemAsText( & $params )
	{
		// Do nothing.
	}


	/**
	 * @see Plugin::DisplayItemAsHtml()
	 */
	function DisplayItemAsHtml( & $params )
	{
		$params['data'] = $params['data']."\n<br />".sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'DisplayItemAsHtml' );
	}


	/**
	 * @see Plugin::DisplayItemAsXml()
	 */
	function DisplayItemAsXml( & $params )
	{
		$params['data'] = $params['data']."\n<br />".sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'DisplayItemAsXml' );
	}


	/**
	 * @see Plugin::DisplayItemAsText()
	 */
	function DisplayItemAsText( & $params )
	{
		$params['data'] = $params['data']."\n<br />".sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'DisplayItemAsText' );
	}


	/**
	 * @see Plugin::FilterIpAddress()
	 */
	function FilterIpAddress( & $params )
	{
		$params['data'] = '[[IP:'.$params['data'].' (TEST plugin)]]';
	}


	/**
	 * @see Plugin::BeforeInstall()
	 */
	function BeforeInstall()
	{
		global $Plugins;
		$this->msg( sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'BeforeInstall' ) );
		return true;
	}


	/**
	 * @see Plugin::AfterInstall()
	 */
	function AfterInstall()
	{
		$this->msg(  sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'AfterInstall' ) );
	}


	/**
	 * @see Plugin::BeforeUninstall()
	 */
	function BeforeUninstall()
	{
		$this->msg( sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'BeforeUninstall' ) );
		return true;
	}


	/**
	 * @see Plugin::AfterUserRegistration()
	 */
	function AfterUserRegistration( $params )
	{
		$this->msg( sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'AfterUserRegistration' ).' '.$this->T_('Hello').' '.$params['User']->dget('login').'!' );
	}


	/**
	 * @see Plugin::DisplayLoginFormFieldset()
	 */
	function DisplayLoginFormFieldset( & $params )
	{
		$params['Form']->info_field( $this->T_('TEST plugin'), sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'DisplayLoginFormFieldset' ) );
	}


	/**
	 * @see Plugin::LoginAttempt()
	 */
	function LoginAttempt()
	{
		// $this->msg( 'NO LOGIN!', 'login_error' );
		$this->msg( sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'LoginAttempt' ), 'note' );
	}


	/**
	 * @see Plugin::LoginAttemptNeedsRawPassword()
	 */
	function LoginAttemptNeedsRawPassword()
	{
		return false; // No we don't need raw. (do not implement this method if the answer is no)
	}


	/**
	 * Automagically login every user as "demouser" who is not logged in and does not
	 * try to currently.
	 *
	 * To enable/test it, change the "if-0" check below to "if( 1 )".
	 *
	 * @see Plugin::AlternateAuthentication()
	 */
	function AlternateAuthentication()
	{
		if( 0 ) // you should only enable it for test purposes, because it automagically logs every user in as "demouser"!
		{
			global $Session, $Messages;

			$UserCache = & get_Cache( 'UserCache' );
			if( $demo_User = & $UserCache->get_by_login('demouser') )
			{ // demouser exists:
				$Session->set_User( $demo_User );
				$Messages->add( $this->T_('Logged in as demouser.'), 'success' );
				return true;
			}
		}
	}


	/**
	 * @see Plugin::DisplayValidateAccountFormFieldset()
	 */
	function DisplayValidateAccountFormFieldset( & $params )
	{
		$params['Form']->info( $this->T_('TEST plugin'), sprintf( $this->T_('This is the TEST plugin responding to the "%s" event.'), 'DisplayValidateAccountFormFieldset' ) );
	}


	/**
	 * Gets provided as plugin event (and gets also used internally for demonstration).
	 *
	 * @param array Associative array of parameters
	 *              'min': mininum number
	 *              'max': maxinum number
	 * @return integer
	 */
	function test_plugin_get_random( & $params )
	{
		return rand( $params['min'], $params['max'] );
	}


	/**
	 * @see Plugin::BeforeSessionsDelete()
	 */
	function BeforeSessionsDelete( $params )
	{
		$this->debug_log('BeforeSessionsDelete: Could have prevented the deletion of all sessions older than ' ).date('Y-m-d H:i:s', $params['cutoff_timestamp' ] );
		return;
	}

}
?>
