<?php
/**
 * This file implements the Vimeo Video class of the video plugin for Quam Plures
 *
 * Quam Plures - {@link http://quamplures.net/}
 * Released under GNU GPL License - {@link http://quamplures.net/license.html}
 * @copyright (c) 2010 by the Quam Plures developers - {@link http://quamplures.net/}
 *
 * @package plugins
 * @subpackage video
 */
if( !defined('QP_MAIN_INIT') ) die( 'Please, do not access this page directly.' );

/**
 * Vimeo Video Class
 *
 * @package plugins
 * @subpackage video
 */
class vp_vimeo extends vp_video {

	var $nice_name = 'Vimeo';
	var $homepage = 'http://vimeo.com/';

	/**
	 * Get extra settings for vimeo
	 */
	function GetExtraSettings()
	{
		$r = array(
			'vimeo_title' => array(
				'label' => $this->T_('Show Title'),
				'type' => 'checkbox',
				'defaultvalue' => '1',
				'note' => $this->T_('advanced vimeo option'),
			),
			'vimeo_byline' => array(
				'label' => $this->T_('Show Byline'),
				'type' => 'checkbox',
				'defaultvalue' => '0',
				'note' => $this->T_('advanced vimeo option'),
			),
			'vimeo_portrait' => array(
				'label' => $this->T_('Show Portrait'),
				'type' => 'checkbox',
				'defaultvalue' => '0',
				'note' => $this->T_('advanced vimeo option'),
			),
			'vimeo_color' => array(
				'label' => $this->T_('Trim Colors'),
				'type' => 'select',
				'defaultvalue' => 'norm',
				'options' => array(
					'norm' => $this->T_('normal (default)'),
					'blue' => $this->T_('blue'),
					'orng' => $this->T_('orange'),
					'lime' => $this->T_('lime'),
					'fsha' => $this->T_('fuschia'),
					'whit' => $this->T_('white'),
				),
				'note' => $this->T_('advanced vimeo option'),
			),
		);
		return $r;
	}


	/**
	 * source-specific javascript
	 */
	function GetJavascript()
	{
		/**
		 * Sample embed :
		 * <object width="400" height="321"><param name="allowfullscreen" value="true" /><param name="allowscriptaccess" value="always" /><param name="movie" value="http://vimeo.com/moogaloop.swf?clip_id=2812778&amp;server=vimeo.com&amp;show_title=1&amp;show_byline=1&amp;show_portrait=0&amp;color=&amp;fullscreen=1" /><embed src="http://vimeo.com/moogaloop.swf?clip_id=2812778&amp;server=vimeo.com&amp;show_title=1&amp;show_byline=1&amp;show_portrait=0&amp;color=&amp;fullscreen=1" type="application/x-shockwave-flash" allowfullscreen="true" allowscriptaccess="always" width="400" height="321"></embed></object><p><a href="http://vimeo.com/2812778">brain</a> from <a href="http://vimeo.com/user1153255">joana oliveira</a> on <a href="http://vimeo.com">Vimeo</a>.</p>
		 *
		 * Sample url :
		 * http://vimeo.com/2812778
		 */
		$r = <<<JAVASCRIPT
var regex = new RegExp( '^.+?width="([0-9]+?)" height="([0-9]+?)".+?vimeo\.com\/.+?clip_id=([0-9]+?)&.+?$', 'i' );
var regexUrl = new RegExp( '^http:\/\/vimeo.com/([0-9]+?)$' );
if( vid_code.match( regex ) ) {
	return '[video:vimeo:'+vid_code.replace( regex, '$3 w:$1 h:$2' )+']';
} else if( vid_code.match( regexUrl ) ) {
	return '[video:vimeo:'+vid_code.replace( regexUrl, '$1' )+']';
} else {
	return false;
}
JAVASCRIPT;

		return $r;
	}


	/**
	 * supports RenderItemAsHtml() in _video.plugin.php
	 */
	function RenderContent( $content, $width )
	{
		if( strpos($content,'[video:vimeo') !== false )
		{
			$extras = '';
			if( $this->Settings->get('vimeo_portrait') )
			{
				$extras .= '&show_portrait=1';
				} else {
				$extras .= '&show_portrait=0';
				}
			if( $this->Settings->get('vimeo_title') )
			{
				$extras .= '&show_title=1';
				} else {
				$extras .= '&show_title=0';
				}
			if( $this->Settings->get('vimeo_byline') )
			{
				$extras .= '&show_byline=1';
				} else {
				$extras .= '&show_byline=0';
				}
			switch( $this->Settings->get('vimeo_color') )
			{
				case 'blue':
				$extras .= '&color=00ADEF';
				break;
				case 'orng':
				$extras .= '&color=FF9933';
				break;
				case 'lime':
				$extras .= '&color=C9FF23';
				break;
				case 'fsha':
				$extras .= '&color=FF0179';
				break;
				case 'whit':
				$extras .= '&color=FFFFFF';
				break;
				}
			$content = preg_replace( '#\[video:vimeo:(.+?) w:(.+?) h:(.+?)]#', '<div class="videoblock"><object type="application/x-shockwave-flash" data="http://www.vimeo.com/moogaloop.swf?clip_id=\\1'.$extras.'" [vimeoscale:\\2:\\3]><param name="movie" value="http://www.vimeo.com/moogaloop.swf?clip_id=\\1'.$extras.'" /><param name="allowfullscreen" value="true" /><param name="wmode" value="transparent" /></object></div>', $content );

			//@todo yabs > tidy this up
			$content = preg_replace( '#\[video:vimeo:(.+?)]#', '<div class="videoblock"><object type="application/x-shockwave-flash" data="http://www.vimeo.com/moogaloop.swf?clip_id=$1'.$extras.'" [vimeoscale:400:225]><param name="movie" value="http://www.vimeo.com/moogaloop.swf?clip_id=\\1'.$extras.'" /><param name="allowfullscreen" value="true" /><param name="wmode" value="transparent" /></object></div>', $content );

			while( substr( $content,strpos($content,'[vimeoscale') +12,3 ) > 0 )
			{
				$orig_height = substr($content,strpos($content,'[vimeoscale')+16,3);
				$orig_width = substr($content,strpos($content,'[vimeoscale')+12,3);
				$height = round( ( $width * $orig_height ) / $orig_width );
				$content = preg_replace( '#\[vimeoscale:(.+?)]#', 'width="'.$width.'" height="'.$height.'"', $content, $limit= 1 );
			}
		}
		return $content;
	}
}
?>
