<?php
/**
 * This file implements the YouTube Video class of the video plugin for Quam Plures
 *
 * Quam Plures - {@link http://quamplures.net/}
 * Released under GNU GPL License - {@link http://quamplures.net/license.html}
 * @copyright (c) 2010 by the Quam Plures developers - {@link http://quamplures.net/}
 *
 * @package plugins
 * @subpackage video
 */
if( !defined('QP_MAIN_INIT') ) die( 'Please, do not access this page directly.' );

/**
 * YouTube Video Class
 *
 * @package plugins
 * @subpackage video
 */
class vp_youtube extends vp_video {

	var $nice_name = 'You Tube!';
	var $homepage = 'http://youtube.com';

	/**
	 * Get extra settings for youtube
	 */
	function GetExtraSettings()
	{
		$r = array(
			'youtube_related' => array(
				'label' => $this->T_('Include related videos'),
				'type' => 'checkbox',
				'defaultvalue' => '0',
				'note' => $this->T_('advanced youtube option'),
			),
			'youtube_border' => array(
				'label' => $this->T_('Show Border'),
				'type' => 'checkbox',
				'defaultvalue' => '0',
				'note' => $this->T_('advanced youtube option'),
			),
			'youtube_color' => array(
				'label' => $this->T_('Trim Colors'),
				'type' => 'select',
				'defaultvalue' => 'none',
				'options' => array(
					'none' => $this->T_('light grays (default)'),
					'gray' => $this->T_('dark grays'),
					'dblu' => $this->T_('dark blues'),
					'lblu' => $this->T_('light blues'),
					'gren' => $this->T_('greens'),
					'orng' => $this->T_('oranges'),
					'pink' => $this->T_('pinks'),
					'prpl' => $this->T_('purples'),
					'reds' => $this->T_('reds'),
				),
				'note' => $this->T_('advanced youtube option'),
			),
		);
		return $r;
	}


	/**
	 * source-specific javascript
	 */
	function GetJavascript()
	{

		/**
		 * Sample embed :
		 * <object width="560" height="340"><param name="movie" value="http://www.youtube.com/v/xGQJuALzNGo&hl=en_GB&fs=1&"></param><param name="allowFullScreen" value="true"></param><param name="allowscriptaccess" value="always"></param><embed src="http://www.youtube.com/v/xGQJuALzNGo&hl=en_GB&fs=1&" type="application/x-shockwave-flash" allowscriptaccess="always" allowfullscreen="true" width="560" height="340"></embed></object>
		 *
		 * Sample link :
		 * http://www.youtube.com/watch?v=xGQJuALzNGo
		 *
		 * Sample url :
		 * http://www.youtube.com/watch?v=xGQJuALzNGo&feature=featured
		 */
		$r = <<<JAVASCRIPT
var regex = new RegExp( '^.+?width="([0-9]+?)" height="([0-9]+?)".+?youtube\.com\/v\/(.+?)&.+?$', 'i' );
var regexUrl = new RegExp( '^.+?youtube.com\/.+?v=(.+?)(&.+?)?$' );
if( vid_code.match( regex ) ) {
	return '[video:youtube:'+vid_code.replace( regex, '$3 w:$1 h:$2' )+']';
} else if( vid_code.match( regexUrl ) ) {
	return '[video:youtube:'+vid_code.replace( regexUrl, '$1' )+']';
} else {
	return false;
}
JAVASCRIPT;

		return $r;
	}


	/**
	 * supports RenderItemAsHtml() in _video.plugin.php
	 */
	function RenderContent( $content, $width )
	{
		if( strpos($content,'[video:youtube') !== false )
		{
			$extras = '';
			if( $this->Settings->get('youtube_related') )
			{
				$extras .= '&rel=1';
			} else {
				$extras .= '&rel=0';
			}
			if( $this->Settings->get('youtube_border') )
			{
				$extras .= '&border=1';
				$size = 349;
			} else {
				$extras .= '&border=0';
				$size = 344;
			}
			switch( $this->Settings->get('youtube_color') )
			{
				case 'gray':
				$extras .= '&color1=0x3a3a3a&color2=0x999999';
				break;
				case 'dblu':
				$extras .= '&color1=0x2b405b&color2=0x6b8ab6';
				break;
				case 'lblu':
				$extras .= '&color1=0x006699&color2=0x54abd6';
				break;
				case 'gren':
				$extras .= '&color1=0x234900&color2=0x4e9e00';
				break;
				case 'orng':
				$extras .= '&color1=0xe1600f&color2=0xfebd01';
				break;
				case 'pink':
				$extras .= '&color1=0xcc2550&color2=0xe87a9f';
				break;
				case 'prpl':
				$extras .= '&color1=0x402061&color2=0x9461ca';
				break;
				case 'reds':
				$extras .= '&color1=0x5d1719&color2=0xcd311b';
				break;
				}
			$content = preg_replace( '#\[video:youtube:(.+?) w:(.+?) h:(.+?)]#', '<div class="videoblock">
<object type="application/x-shockwave-flash" data="http://www.youtube.com/v/\\1'.$extras.'" [utubescale:\\2:\\3]>
<param name="movie" value="http://www.youtube.com/v/\\1'.$extras.'" />
<param name="allowfullscreen" value="true" />
<param name="wmode" value="transparent" />
</object></div>', $content );
			while( substr( $content,strpos($content,'[utubescale') +12,3 ) > 0 )
			{
				$orig_width = substr($content,strpos($content,'[utubescale')+12,3);
				$orig_height = substr($content,strpos($content,'[utubescale')+16,3);
				$height = round( ( $width * $orig_height ) / $orig_width );
				$content = preg_replace( '#\[utubescale:(.+?)]#', 'width="'.$width.'" height="'.$height.'"', $content, $limit= 1 );
			}

			/**
			 * @todo EdB: next two lines are probably not needed because they support original
			 * evo embedding method (no width and height params), so maybe we should kill it?
			 */
			$content = preg_replace( '#\[video:youtube:(.+?)]#', '<div class="videoblock"><object type="application/x-shockwave-flash" data="http://www.youtube.com/v/\\1'.$extras.'" [utub:345]><param name="movie" value="http://www.youtube.com/v/\\1'.$extras.'" /><param name="allowfullscreen" value="true" /><param name="wmode" value="transparent" /></object></div>', $content );
			$content = preg_replace( '#\[utub:(.+?)]#', 'width="'.$width.'" height="'.round( ( $width * substr($content,strpos($content,'[utub:')+6,3) ) / 425 ).'"', $content );

		}
		return $content;
	}
}
?>
