<?php
/**
 * This file implements the XML Feeds (RSS / Atom) Widget class.
 *
 * This file is part of Quam Plures - {@link http://quamplures.net/}
 * See also {@link https://launchpad.net/quam-plures}.
 *
 * @copyright (c) 2009 by the Quam Plures developers - {@link http://quamplures.net/}
 * @copyright (c)2003-2009 by Francois PLANQUE - {@link http://fplanque.net/}
 *
 * {@internal License choice
 * - If you have received this file as part of a package, please find the license.txt file in
 *   the same folder or the closest folder above for complete license terms.
 * - If you have received this file individually (e-g: from http://evocms.cvs.sourceforge.net/)
 *   then you must choose one of the following licenses before using the file:
 *   - GNU General Public License 2 (GPL) - http://www.opensource.org/licenses/gpl-license.php
 *   - Mozilla Public License 1.1 (MPL) - http://www.opensource.org/licenses/mozilla1.1.php
 * }}
 *
 * {@internal Below is a list of authors who have contributed to design/coding of this file: }}
 * @author fplanque: Francois PLANQUE.
 *
 * @package widgets
 */
if( !defined('QP_MAIN_INIT') ) die( 'Please, do not access this page directly.' );

load_class( 'widgets/model/_widget.class.php' );


/**
 * @package widgets
 */
class xml_feeds_Widget extends ComponentWidget
{
	/**
	 * Constructor
	 */
	function xml_feeds_Widget( $db_row = NULL )
	{
		// Call parent constructor:
		parent::ComponentWidget( $db_row, 'widget', 'xml_feeds' );

		$this->widget_name = $this->T_('XML Feeds (RSS / Atom)');
		$this->widget_title = '$icon$ '.$this->T_('XML Feeds');
	}


	/**
	 * Get a very short desc. Used in the widget list.
	 */
	function get_short_desc()
	{
		return format_to_output($this->get_title());
	}


  /**
	 * Get short description
	 */
	function get_desc()
	{
		return $this->T_('List of all available XML feeds.');
	}


  /**
   * Get definitions for editable params
   *
	 * @see Plugin::GetDefaultSettings()
	 * @param local params like 'for_editing' => true
	 */
	function get_param_definitions( $params )
	{
		global $use_strict;
		$r = array_merge( array(
				'disp_info_link' => array(
					'label' => $this->T_('Help link'),
					'type' => 'checkbox',
					'note' => $this->T_('Check this to display "What is RSS?" link'),
					'defaultvalue' => 1,
				),
				'info_link' => array(
					'label' => $this->T_('New Window'),
					'type' => 'checkbox',
					'note' => $this->T_('Check this to add target="_blank" to the "What is RSS?" link'),
					'defaultvalue' => !$use_strict,
				),
			), parent::get_param_definitions( $params )	);

		return $r;
	}


/**
 * dummy docblock makes error-free autodocs
 */
	function get_title()
	{
		global $rsc_url;

		$title = str_replace( '$icon$', get_icon( 'feed' ).' ', $this->disp_params['widget_title']);

		return $title;
	}


	/**
	 * Display the widget!
	 *
	 * @param array MUST contain at least the basic display params
	 */
	function display( $params )
	{
		global $Blog;

		$this->init_display( $params );

		// Available XML feeds:
		echo $this->disp_params['block_start'];

		$this->disp_title( $this->get_title() );

		echo $this->disp_params['list_start'];

		$TemplateCache = & get_Cache( 'TemplateCache' );
		$TemplateCache->load_by_type( 'feed' );

		// TODO: this is like touching private parts :>
		foreach( $TemplateCache->cache as $Template )
		{
			if( $Template->type != 'feed' )
			{	// This template cannot be used here...
				continue;
			}

			echo $this->disp_params['item_start'];
			echo $Template->name.': ';
			echo '<a href="'.$Blog->get_item_feed_url( $Template->folder ).'" title="'.T_('subscribe to this blogs posts').'">'.$this->T_('Posts').'</a>';
			if ( $Blog->allowcomments != 'never' )
			{
				echo ', <a href="'.$Blog->get_comment_feed_url( $Template->folder ).'" title="'.T_('subscribe to this blogs comments').'">'.$this->T_('Comments').'</a>';
			}

			echo $this->disp_params['item_end'];
		}

		echo $this->disp_params['list_end'];


		// Display "info" link, if activated.
		if( $this->disp_params['disp_info_link'] )
		{
			/**
			 * @todo EdB: the displayed text needs to be translatable
			 *       Tblue> ...but only if the link can be customized => make it customizable.
			 */
			$feedhelp = '<a href="http://www.whatisrss.com" title="http://www.whatisrss.com"';
			if( $this->disp_params[ 'info_link' ] )
			{
				$feedhelp .= ' target="_blank"';
			}
			$feedhelp .= '>What is RSS?</a>';

			echo $feedhelp;

		}

		echo $this->disp_params['block_end'];

		return true;
	}
}


?>
