<?php
/**
 * Generates an Atom feed for the requested blog's latest comments
 *
 * See {@link http://atompub.org/2005/07/11/draft-ietf-atompub-format-10.html}
 *
 * @package xml
 * @subpackage atom
 */
if( !defined('QP_MAIN_INIT') ) die( 'Please, do not access this page directly.' );

if( isset($Item) )
{ // Comments for a specific Item:
	$CommentList = new CommentList( $Blog, "'comment'", array('published'), $Item->ID, '', 'DESC', '', $Blog->get_setting('posts_per_feed') );
}
else
{ // Comments for the blog:
	$CommentList = new CommentList( $Blog, "'comment'", array('published'), '', '', 'DESC', '', $Blog->get_setting('posts_per_feed') );
}

if( $debug)
{
	header_content_type( 'application/xml' ); // sets charset
}
else
{
	header_content_type( 'application/atom+xml' ); // sets charset
}

echo '<?xml version="1.0" encoding="'.$io_charset.'"?'.'>';
?>
<feed xml:lang="<?php $Blog->disp( 'locale', 'xml' ) ?>" xmlns="http://www.w3.org/2005/Atom">
	<title><?php
		$Blog->disp( 'name', 'xml' );
		// title for the current request
		request_title( array(
			'title_before' => ' - ',
			'format' => 'xml',
		) ); ?></title>
	<link rel="alternate" type="text/html" href="<?php $Blog->disp( 'lastcommentsurl', 'xml' ) ?>" />
	<link rel="self" type="application/atom+xml" href="<?php $Blog->disp( 'comments_atom_url', 'xmlattr' ) ?>" />
	<id><?php $Blog->disp( 'comments_atom_url', 'xmlattr' ) /* TODO: may need a regenerate_url() */ ?></id>
	<generator uri="http://quamplures.net/" version="<?php echo $app_version ?>"><?php echo $app_name ?></generator>
	<updated><?php echo gmdate('Y-m-d\TH:i:s\Z'); ?></updated>
	<?php while( $Comment = & $CommentList->get_next() )
	{ /* Loop through comments: */ ?>
	<entry>
		<title type="text"><?php echo format_to_output( $Template->T_('In response to').':', 'xml' ).' ';
			$Comment->get_Item();
			$Comment->Item->title( array( 'format' => 'xml', 'link_type' => 'none' ) ); ?></title>
		<link rel="alternate" type="text/html" href="<?php $Comment->permanent_url(); ?>" />
		<author>
			<name><?php $Comment->author( array( 'format' => 'xml' ) ); ?></name>
			<?php $Comment->author_url( array( 'before' => '<uri>', 'after' => "</uri>\n", 'make_link' => false ) ); ?>
		</author>
		<id><?php $Comment->permanent_url(); ?></id>
		<published><?php $Comment->date( array( 'format' => 'isoZ', 'useGM' => true ) ); ?></published>
		<updated><?php $Comment->date( array( 'format' => 'isoZ', 'useGM' => true ) ); ?></updated>
		<content type="html"><![CDATA[<?php echo make_rel_links_abs( $Comment->get_content() ); ?>]]></content>
	</entry>
	<?php
} // End of comment loop.
?>
</feed>
<?php $Hit->log(); // log the hit on this page ?>
