<?php
/**
 * Template Class file
 *
 * This file is part of the Quam Plures project - {@link http://quamplures.net/}
 *
 * @package templates
 * @subpackage custom
 */
if( !defined('QP_MAIN_INIT') ) die( 'Please, do not access this page directly.' );

/**
 * template class
 *
 * @package templates
 * @subpackage custom
 */
class custom_Template extends Template
{

	/**
	 * Get default name for the template, which the admin can customize.
	 */
	function get_default_name()
	{
		return 'Custom';
	}


	/**
	 * Get default type for the template.
	 */
	function get_default_type()
	{
		return 'normal';
	}


	/**
	 * Get definitions for editable params
	 *
	 * @see Plugin::GetDefaultSettings()
	 */
	function get_param_definitions( $params )
	{
		$r = array_merge( array(
				'head_bg_color' => array(
					'label' => $this->T_('Header Background Color'),
					'note' => $this->T_('E-g: #ff0000 for red'),
					'defaultvalue' => '#78a',
					'valid_pattern' => array(
						'pattern' => '^(#([a-f0-9]{3}){1,2})?$i',
						'error' =>T_('Invalid color code.'),
					),
				),
				'menu_bg_color' => array(
					'label' => $this->T_('Menu Background Color'),
					'note' => $this->T_('E-g: #ff0000 for red'),
					'defaultvalue' => '#ddd',
					'valid_pattern' => array(
						'pattern' => '^(#([a-f0-9]{3}){1,2})?$i',
						'error' =>T_('Invalid color code.'),
					),
				),
			), parent::get_param_definitions( $params )	);
		return $r;
	}


	/**
	 * Get ready for displaying the template.
	 *
	 * This may register some CSS or JS...
	 */
	function display_init()
	{
		// call parent:
		parent::display_init();

		// Add custom CSS:
		$custom_css = '';

		if( $bg_color = $this->get_setting( 'head_bg_color') )
		{ // Custom Header background color:
			$custom_css .= ' div.pageHeader { background-color: '.$bg_color." }\n";
		}

		if( $bg_color = $this->get_setting( 'menu_bg_color') )
		{ // Custom Meu background color:
			$custom_css .= ' div.top_menu ul { background-color: '.$bg_color." }\n";
		}

		if( !empty( $custom_css ) )
		{
			$custom_css = '
			<style type="text/css">
			<!--
			'.$custom_css.' -->
			</style>';
			add_headline( $custom_css );
		}

	}


	/**
	 * Get credits for linkback on credits page.
	 * see http://docs.quamplures.net/templates/Template.html#methodget_template_credits
	 */
	function get_template_credits()
	{
		$template_linkbacks = array(
			'designer' => array(
				'pre' => $this->T_('Design by'),
				'text' => 'Fran&ccedil;ois PLANQUE',
				'post' => '', /* Replace with $this->T_('...') when there is something to translate */
				'url' => 'http://fplanque.net/',
				'title' => 'http://fplanque.net/',
			),
			'ported' => array(
				'pre' => $this->T_('Ported by'),
				'text' => 'EdB',
				'post' => '', /* Replace with $this->T_('...') when there is something to translate */
				'url' => 'http://1912webworks.com/',
				'title' => $this->T_('insert creative link title'),
			),
		);
		return $template_linkbacks;
	}

}

?>
