<?php
/**
 * "item feedback" sub-template

Need help doing something with this file?
http://docs.quamplures.net/li_templates.html - tutorials and autodocs

 * This is meant to be included via a .main.php (or other .inc.php) file
 *
 * Quam Plures - {@link http://quamplures.net/}
 * Released under GNU GPL License - {@link http://quamplures.net/license.html}
 * @copyright (c) 2009 by the Quam Plures developers - {@link http://quamplures.net/}
 * @copyright (c)2003-2009 by Francois PLANQUE - {@link http://fplanque.net/}
 * @package templates
 * @subpackage glossyblue
 */
if( !defined('QP_MAIN_INIT') ) die( 'Please, do not access this page directly.' );

// set some default params...
$params = array_merge( array(
	'disp_comments' => true,
	'disp_comment_form' => true,
	'disp_trackbacks' => true,
	'disp_trackback_url' => true,
	'before_section_title' => '<h3>',
	'after_section_title' => '</h3>',
	'form_title_start' => '<h3>',
	'form_title_end' => '</h3>',
), $params );

global $c, $tb, $comment_allowed_tags, $comments_use_autobr;

global $cookie_name, $cookie_email, $cookie_url;

if( ! $Item->can_see_comments() )
{ // Comments are disabled for this post
	return;
}

if( empty($c) )
{ // Comments not requested
	$params['disp_comments'] = false;
	$params['disp_comment_form'] = false;
}

if( empty($tb) || !$Blog->get( 'allowtrackbacks' ) )
{ // Trackback not requested or not allowed
	$params['disp_trackbacks'] = false;
	$params['disp_trackback_url'] = false;
}

if( ! ($params['disp_comments'] || $params['disp_comment_form'] || $params['disp_trackbacks'] || $params['disp_trackback_url'] ) )
{ // Nothing more to do....
	return false;
}

echo '<a id="feedbacks"></a>';

$type_list = array();
$disp_title = array();

if( $params['disp_comments'] )
{ // We requested to display comments
	if( $Item->can_see_comments() )
	{ // User can see a comments
		$type_list[] = "'comment'";
		if( $title = $Item->get_feedback_title( 'comments' ) )
		{
			$disp_title[] = $title;
		}
	}
	else
	{ // Use cannot see comments
		$params['disp_comments'] = false;
	}
	echo '<a id="comments"></a>';
}

if( $params['disp_trackbacks'] )
{
	$type_list[] = "'trackback'";
	if( $title = $Item->get_feedback_title( 'trackbacks' ) )
	{
		$disp_title[] = $title;
	}
	echo '<a id="trackbacks"></a>';
}

if( $params['disp_trackback_url'] )
{ // We want to display the trackback URL:

	echo $params['before_section_title'];
	echo $Template->T_('Trackback address for this post');
	echo $params['after_section_title'];

	/*
	 * Trigger plugin event, which could display a captcha form, before generating a whitelisted URL:
	 */
	if( ! $Plugins->trigger_event_first_true( 'DisplayTrackbackAddr', array('Item' => & $Item, 'template' => '<code>%url%</code>') ) )
	{ // No plugin displayed a payload, so we just display the default:
		echo '<p class="trackback_url"><a href="'.$Item->get_trackback_url().'">'.$Template->T_('Trackback URL (right click and copy shortcut/link location)').'</a></p>';
	}
}

if( $params['disp_comments'] || $params['disp_trackbacks'] )
{
	if( empty($disp_title) )
	{ // No title yet
		if( $title = $Item->get_feedback_title( 'feedbacks', '', $Template->T_('Feedback awaiting moderation'), $Template->T_('Feedback awaiting moderation'), 'draft' ) )
		{ // We have some feedback awaiting moderation: we'll want to show that in the title
			$disp_title[] = $title;
		}
	}

	if( empty($disp_title) )
	{ // Still no title
		$disp_title[] = $Template->T_('No feedback yet');
	}

	echo $params['before_section_title'];
	echo implode( ', ', $disp_title);
	echo $params['after_section_title'];

	$CommentList = new CommentList( NULL, implode(',', $type_list), array('published'), $Item->ID, '', 'ASC' );
	?>

	<ol class="commentlist">
	<?php
	// This variable is for alternating comment background
	$oddcomment = 'alt';
	/**
	 * @var Comment
	 */
	while( $Comment = & $CommentList->get_next() )
	{ // Loop through comments:
		?>
		<li id="comment-<?php $Comment->ID(); ?>" class="<?php echo $oddcomment; ?>">
		<?php
		$Comment->anchor(); // display an anchor for for this comment
		switch( $Comment->get( 'type' ) )
		{
			case 'comment':
				// display a permalink link to the comment
				$Comment->permanent_link( array(
					'text' => '&#167; ',
					'nofollow' => true,
				) );

				// display comment author's name
				$Comment->author( array(
					'after_user' => '&#174;',
				) );

				$Comment->msgform_link( $Blog->get('msgformurl') );
				echo ' '.$Template->T_('said on :').' <small class="commentmetadata">';

				// display the comment's date
				$Comment->date( array(
					'after' => ' @ ',
				) );

				// display the comment's time
				$Comment->time( array(
					'format' => 'H:i',
				) );

				// display a link to edit a comment
				$Comment->edit_link( array(
					'text' => get_icon( 'edit' ),
				) );

				// display a link to delete a comment
				$Comment->delete_link( array(
					'text' => get_icon( 'delete' ),
				) );
				echo '</small>';
				break;

			case 'trackback':
				// display a permalink link to the trackback
				$Comment->permanent_link( array(
					'text' => $Template->T_('Trackback'),
					'nofollow' => true,
				) );

				// display trackback author's name
				$Comment->author( array(
					'before_user' => ' '.$Template->T_('from').': ',
				) );
				break;

		}

		// display a comment's rating
		$Comment->rating( array() );
		?>

		<div class="bCommentText">
		<?php $Comment->content(); ?>
		</div>

		<div class="bCommentSmallPrint">
		</div>

		</li>
		<?php // Changes every other comment to a different class
		if ('alt' == $oddcomment)
		{
			$oddcomment = '';
		}
		else
		{
			$oddcomment = 'alt';
		}
	} // End of comment list loop.
	?>
	</ol>
	<?php
	// Display count of comments to be moderated:
	$Item->feedback_moderation( 'feedbacks', '<div class="moderation_msg"><p>', '</p></div>', '',
		$Template->T_('This post has 1 feedback awaiting moderation... %s'),
		$Template->T_('This post has %d feedbacks awaiting moderation... %s') );

	if( $Blog->get_setting( 'feed_content' ) != 'none' )
	{ 
		// Display link for comments feed:
		$Item->feedback_feed_link( '_rss2', '<div class="feedback_feed_msg"><p>', '</p></div>' );
	}

}

/*
 * Comment form:
 */
if( $params['disp_comment_form'] && $Item->can_comment() )
{ // We want to display the comments form and the item can be commented on:

	if( $Comment = $Session->get('core.preview_Comment') )
	{ // We have a comment to preview
		if( $Comment->item_ID == $Item->ID )
		{ // display PREVIEW:
			?>
			<div class="bComment" id="comment_preview">

			<div class="bCommentTitle">
			<?php
			echo $Template->T_('PREVIEW Comment from:').' ';
			// display comment author's name
			$Comment->author( array() );

			// display a link to message form for this comment's author
			$Comment->msgform_link( $Blog->get('msgformurl'), array() );

			// display a link to comment author's URL
			$Comment->author_url( array(
				'before' => ' &middot; ',
			) )
			?>
			</div>

			<div class="bCommentText">
			<?php $Comment->content(); // display the comment's contents ?>
			</div>

			<div class="bCommentSmallPrint">
			<?php 
			// display the comment's date
			$Comment->date( array(
				'after' => ' @ ',
			) );

			// display the comment's time
			$Comment->time( array(
				'format' => 'H:i',
			) );
			?>
			</div>

			</div>

			<?php
			// Form fields:
			$comment_content = $Comment->original_content;
			// for visitors:
			$comment_author = $Comment->author;
			$comment_author_email = $Comment->author_email;
			$comment_author_url = $Comment->author_url;
		}

		// delete any preview comment from session data:
		$Session->delete( 'core.preview_Comment' );
	}
	else
	{ // New comment:
		$Comment = new Comment();
		$comment_author = isset($_COOKIE[$cookie_name]) ? trim($_COOKIE[$cookie_name]) : '';
		$comment_author_email = isset($_COOKIE[$cookie_email]) ? trim($_COOKIE[$cookie_email]) : '';
		$comment_author_url = isset($_COOKIE[$cookie_url]) ? trim($_COOKIE[$cookie_url]) : '';
		if( empty($comment_author_url) )
		{ // Even if we have a blank cookie, let's reset this to remind the bozos what it's for
			$comment_author_url = 'http://';
		}
		$comment_content = '';
	}

	echo $params['form_title_start'];
	echo $Template->T_('Leave a comment');
	echo $params['form_title_end'];

	$Form = new Form( $srvc_url.'comment_post.php', 'bComment_form_id_'.$Item->ID, 'post' );
	$Form->begin_form( 'bComment', '', array( 'target' => '_self' ) );
	/**
	 * @todo (legacy): dh> a plugin hook would be useful here to add something to 
	 * the top of the Form. Actually, the best would be, if the $Form object could 
	 * be changed by a plugin before display!
	 */
	$Form->hidden( 'comment_post_ID', $Item->ID );
	$Form->hidden( 'redirect_to',
	// Make sure we get back to the right page (on the right domain)
	/**
	 * @todo (legacy): fplanque>> check if we can use the permalink instead but we 
	 * must check that application wide, that is to say: check with the comments 
	 * in a pop-up etc...
	 */
	url_rel_to_same_host(regenerate_url( '', '', $Blog->get('blogurl'), '&' ), $srvc_url) );
	if( is_logged_in() )
	{ // User is logged in:
		$Form->begin_fieldset();
		$Form->info_field( $Template->T_('User'), '<strong>'.$current_User->get_preferred_name().'</strong>'
			.' '.get_user_profile_link( ' [', ']', $Template->T_('Edit profile') ) );
		$Form->end_fieldset();
	}
	else
	{ // User is not logged in:
		// Note: we use funky field names to defeat the most basic guestbook spam bots
		$Form->text( 'u', $comment_author, 40, $Template->T_('Name'), '', 100, 'bComment' );
		$Form->text( 'i', $comment_author_email, 40, $Template->T_('Email'), '<br />'.$Template->T_('Your email address will <strong>not</strong> be revealed on this site.'), 100, 'bComment' );
		$Form->text( 'o', $comment_author_url, 40, $Template->T_('Website'), '<br />'.$Template->T_('Your URL will be displayed.'), 100, 'bComment' );
	}

	if( $Item->can_rate() )
	{ // Comment rating:
		$Form->begin_fieldset();
			echo $Form->begin_field( NULL, $Template->T_('Your vote'), true );
			// display options to rate a comment
			$Comment->rating_input( array() );
			echo $Form->end_field();
		$Form->end_fieldset();
	}

	echo '<div class="comment_toolbars">';
	// CALL PLUGINS NOW:
	$Plugins->trigger_event( 'DisplayCommentToolbar', array() );
	echo '</div>';

	// Message field:
	$note = '';
	// $note = $Template->T_('Allowed XHTML tags').': '.htmlspecialchars(str_replace( '><',', ', $comment_allowed_tags));
	$Form->textarea( 'p', $comment_content, 10, $Template->T_('Comment text'), $note, 45, 'bComment' );

	// set app_Canvas for plugins
	echo '<script type="text/javascript">var app_Canvas = document.getElementById( "p" );</script>';

	$comment_options = array();

	if( substr($comments_use_autobr,0,4) == 'opt-')
	{
		$comment_options[] = '<label><input type="checkbox" class="checkbox" name="comment_autobr" tabindex="6"'
			.( ($comments_use_autobr == 'opt-out') ? ' checked="checked"' : '' )
			.' value="1" /> '.$Template->T_('Auto-BR').'</label>'
			.' <span class="note">('.$Template->T_('Line breaks become &lt;br /&gt;').')</span>';
	}

	if( ! is_logged_in() )
	{ // User is not logged in:
		$comment_options[] = '<label><input type="checkbox" class="checkbox" name="comment_cookies" tabindex="7"'
			.' checked="checked" value="1" /> '.$Template->T_('Remember me').'</label>'
			.' <span class="note">('.$Template->T_('Name, email &amp; website').')</span>';
	/**
	 * @todo (legacy): If we got info from cookies, Add a link called "Forget me now!" (without posting a comment).
	 */

		$comment_options[] = '<label><input type="checkbox" class="checkbox" name="comment_allow_msgform" tabindex="8"'
			.' checked="checked" value="1" /> '.$Template->T_('Allow message form').'</label>'
			.' <span class="note">('.$Template->T_('Allow users to contact you through a message form (your email will <strong>not</strong> be revealed.').')</span>';
	/**
	 * @todo (legacy): If we have an email in a cookie, Add links called "Add a contact icon to all my previous comments" and "Remove contact icon from all my previous comments".
	 */
	}

	if( ! empty($comment_options) )
	{
		$Form->begin_fieldset();
			echo $Form->begin_field( NULL, $Template->T_('Options'), true );
			echo implode( '<br />', $comment_options );
			echo $Form->end_field();
		$Form->end_fieldset();
	}

	$Plugins->trigger_event( 'DisplayCommentFormFieldset', array( 'Form' => & $Form, 'Item' => & $Item ) );

	$Form->begin_fieldset();
		echo '<div class="input">';

		$Form->button_input( array(
			'name' => 'submit_comment_post_'.$Item->ID.'[save]',
			'class' => 'submit',
			'value' => $Template->T_('Send comment'),
			'tabindex' => 10,
		) );
		$Form->button_input( array(
			'name' => 'submit_comment_post_'.$Item->ID.'[preview]',
			'class' => 'submit',
			'value' => $Template->T_('Preview'),
			'tabindex' => 9,
		) );

		$Plugins->trigger_event( 'DisplayCommentFormButton', array( 'Form' => & $Form, 'Item' => & $Item ) );

		echo '</div>';
	$Form->end_fieldset();
	?>

	<div class="clear"></div>

	<?php
	$Form->end_form();
}
?>
